window.mapStyles = new Object();

window.mapStyles["none"] = {name: "None", version: 8, sources: {}, layers: []};

window.mapStyles["osm"] = {
  name: "OpenStreetMap",
  "version": 8,
  "sources": {
    "osm": {
      "type": "raster",
      "tiles": ["https://a.tile.openstreetmap.org/{z}/{x}/{y}.png"],
      "tileSize": 256,
      "attribution": "&copy; OpenStreetMap Contributors",
      "maxzoom": 19
    }
  },
  "layers": [
    {
      "id": "osm",
      "type": "raster",
      "source": "osm"
    }
  ]
};

window.mapStyles["darkmatter"] = {
    "version": 8,
    "name": "Dark Matter",
    "metadata": {
        "maputnik:renderer": "mbgljs"
    },
    "sources": {
        "carto": {
            "type": "vector",
            "url": "https://tiles.basemaps.cartocdn.com/vector/carto.streets/v1/tiles.json"
        }
    },
    "sprite": "https://tiles.basemaps.cartocdn.com/gl/dark-matter-gl-style/sprite",
    "glyphs": "https://tiles.basemaps.cartocdn.com/fonts/{fontstack}/{range}.pbf",
    "layers": [
        {
            "id": "background",
            "type": "background",
            "layout": {
                "visibility": "visible"
            },
            "paint": {
                "background-color": "#0e0e0e",
                "background-opacity": 1
            }
        },
        {
            "id": "landcover",
            "type": "fill",
            "source": "carto",
            "source-layer": "landcover",
            "filter": [
                "any",
                [
                    "==",
                    "class",
                    "wood"
                ],
                [
                    "==",
                    "class",
                    "grass"
                ],
                [
                    "==",
                    "subclass",
                    "recreation_ground"
                ]
            ],
            "paint": {
                "fill-color": {
                    "stops": [
                        [
                            8,
                            "#0e0e0e"
                        ],
                        [
                            9,
                            "#0e0e0e"
                        ],
                        [
                            11,
                            "#0e0e0e"
                        ],
                        [
                            13,
                            "#0e0e0e"
                        ],
                        [
                            15,
                            "#0e0e0e"
                        ]
                    ]
                },
                "fill-opacity": 1
            }
        },
        {
            "id": "park_national_park",
            "type": "fill",
            "source": "carto",
            "source-layer": "park",
            "minzoom": 9,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "national_park"
                ]
            ],
            "layout": {
                "visibility": "visible"
            },
            "paint": {
                "fill-color": {
                    "stops": [
                        [
                            8,
                            "#0e0e0e"
                        ],
                        [
                            9,
                            "#0e0e0e"
                        ],
                        [
                            11,
                            "#0e0e0e"
                        ],
                        [
                            13,
                            "#0e0e0e"
                        ],
                        [
                            15,
                            "#0e0e0e"
                        ]
                    ]
                },
                "fill-opacity": 1,
                "fill-translate-anchor": "map"
            }
        },
        {
            "id": "park_nature_reserve",
            "type": "fill",
            "source": "carto",
            "source-layer": "park",
            "minzoom": 0,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "nature_reserve"
                ]
            ],
            "layout": {
                "visibility": "visible"
            },
            "paint": {
                "fill-color": {
                    "stops": [
                        [
                            8,
                            "#0e0e0e"
                        ],
                        [
                            9,
                            "#0e0e0e"
                        ],
                        [
                            11,
                            "#0e0e0e"
                        ],
                        [
                            13,
                            "#0e0e0e"
                        ],
                        [
                            15,
                            "#0e0e0e"
                        ]
                    ]
                },
                "fill-antialias": true,
                "fill-opacity": {
                    "stops": [
                        [
                            6,
                            0.7
                        ],
                        [
                            9,
                            0.9
                        ]
                    ]
                }
            }
        },
        {
            "id": "landuse_residential",
            "type": "fill",
            "source": "carto",
            "source-layer": "landuse",
            "minzoom": 6,
            "filter": [
                "any",
                [
                    "==",
                    "class",
                    "residential"
                ]
            ],
            "paint": {
                "fill-color": {
                    "stops": [
                        [
                            5,
                            "rgba(0, 0, 0, 0.5)"
                        ],
                        [
                            8,
                            "rgba(0, 0, 0, 0.45)"
                        ],
                        [
                            9,
                            "rgba(0, 0, 0, 0.4)"
                        ],
                        [
                            11,
                            "rgba(0, 0, 0, 0.35)"
                        ],
                        [
                            13,
                            "rgba(0, 0, 0, 0.3)"
                        ],
                        [
                            15,
                            "rgba(0, 0, 0, 0.25)"
                        ],
                        [
                            16,
                            "rgba(0, 0, 0, 0.15)"
                        ]
                    ]
                },
                "fill-opacity": {
                    "stops": [
                        [
                            6,
                            0.6
                        ],
                        [
                            9,
                            1
                        ]
                    ]
                }
            }
        },
        {
            "id": "landuse",
            "type": "fill",
            "source": "carto",
            "source-layer": "landuse",
            "filter": [
                "any",
                [
                    "==",
                    "class",
                    "cemetery"
                ],
                [
                    "==",
                    "class",
                    "stadium"
                ]
            ],
            "paint": {
                "fill-color": {
                    "stops": [
                        [
                            8,
                            "#0e0e0e"
                        ],
                        [
                            9,
                            "#0e0e0e"
                        ],
                        [
                            11,
                            "#0e0e0e"
                        ],
                        [
                            13,
                            "#0e0e0e"
                        ],
                        [
                            15,
                            "#0e0e0e"
                        ]
                    ]
                }
            }
        },
        {
            "id": "waterway",
            "type": "line",
            "source": "carto",
            "source-layer": "waterway",
            "paint": {
                "line-color": "rgba(63, 90, 109, 1)",
                "line-width": {
                    "stops": [
                        [
                            8,
                            0.5
                        ],
                        [
                            9,
                            1
                        ],
                        [
                            15,
                            2
                        ],
                        [
                            16,
                            3
                        ]
                    ]
                }
            }
        },
        {
            "id": "boundary_county",
            "type": "line",
            "source": "carto",
            "source-layer": "boundary",
            "minzoom": 9,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "admin_level",
                    6
                ],
                [
                    "==",
                    "maritime",
                    0
                ]
            ],
            "paint": {
                "line-color": {
                    "stops": [
                        [
                            4,
                            "#222"
                        ],
                        [
                            5,
                            "#222"
                        ],
                        [
                            6,
                            "#2C353C"
                        ]
                    ]
                },
                "line-width": {
                    "stops": [
                        [
                            4,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-dasharray": {
                    "stops": [
                        [
                            6,
                            [
                                1
                            ]
                        ],
                        [
                            7,
                            [
                                2,
                                2
                            ]
                        ]
                    ]
                }
            }
        },
        {
            "id": "boundary_state",
            "type": "line",
            "source": "carto",
            "source-layer": "boundary",
            "minzoom": 4,
            "filter": [
                "all",
                [
                    "==",
                    "admin_level",
                    4
                ],
                [
                    "==",
                    "maritime",
                    0
                ]
            ],
            "paint": {
                "line-color": {
                    "stops": [
                        [
                            4,
                            "rgba(103, 103, 114, 1)"
                        ],
                        [
                            5,
                            "rgba(103, 103, 114, 1)"
                        ],
                        [
                            6,
                            "rgba(103, 103, 114, 1)"
                        ]
                    ]
                },
                "line-width": {
                    "stops": [
                        [
                            4,
                            0.5
                        ],
                        [
                            7,
                            1
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            9,
                            1.2
                        ]
                    ]
                },
                "line-dasharray": {
                    "stops": [
                        [
                            6,
                            [
                                1,
                                2,
                                3
                            ]
                        ],
                        [
                            7,
                            [
                                1,
                                2,
                                3
                            ]
                        ]
                    ]
                }
            }
        },
        {
            "id": "water",
            "type": "fill",
            "source": "carto",
            "source-layer": "water",
            "minzoom": 0,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "$type",
                    "Polygon"
                ]
            ],
            "layout": {
                "visibility": "visible"
            },
            "paint": {
                "fill-color": "#2C353C",
                "fill-antialias": true,
                "fill-translate-anchor": "map",
                "fill-opacity": 1
            }
        },
        {
            "id": "water_shadow",
            "type": "fill",
            "source": "carto",
            "source-layer": "water",
            "minzoom": 0,
            "filter": [
                "all",
                [
                    "==",
                    "$type",
                    "Polygon"
                ]
            ],
            "layout": {
                "visibility": "visible"
            },
            "paint": {
                "fill-color": "transparent",
                "fill-antialias": true,
                "fill-translate-anchor": "map",
                "fill-opacity": 1,
                "fill-translate": {
                    "stops": [
                        [
                            0,
                            [
                                0,
                                2
                            ]
                        ],
                        [
                            6,
                            [
                                0,
                                1
                            ]
                        ],
                        [
                            14,
                            [
                                0,
                                1
                            ]
                        ],
                        [
                            17,
                            [
                                0,
                                2
                            ]
                        ]
                    ]
                }
            }
        },
        {
            "id": "aeroway-runway",
            "type": "line",
            "source": "carto",
            "source-layer": "aeroway",
            "minzoom": 12,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "runway"
                ]
            ],
            "layout": {
                "line-cap": "square"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            1
                        ],
                        [
                            13,
                            4
                        ],
                        [
                            14,
                            6
                        ],
                        [
                            15,
                            8
                        ],
                        [
                            16,
                            10
                        ]
                    ]
                },
                "line-color": "#111"
            }
        },
        {
            "id": "aeroway-taxiway",
            "type": "line",
            "source": "carto",
            "source-layer": "aeroway",
            "minzoom": 13,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "taxiway"
                ]
            ],
            "paint": {
                "line-color": "#111",
                "line-width": {
                    "stops": [
                        [
                            13,
                            0.5
                        ],
                        [
                            14,
                            1
                        ],
                        [
                            15,
                            2
                        ],
                        [
                            16,
                            4
                        ]
                    ]
                }
            }
        },
        {
            "id": "tunnel_service_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "service"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            1
                        ],
                        [
                            16,
                            3
                        ],
                        [
                            17,
                            6
                        ],
                        [
                            18,
                            8
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#1a1a1a"
            }
        },
        {
            "id": "tunnel_minor_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 13,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "minor"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "miter"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            0.5
                        ],
                        [
                            12,
                            0.5
                        ],
                        [
                            14,
                            2
                        ],
                        [
                            15,
                            4
                        ],
                        [
                            16,
                            6
                        ],
                        [
                            17,
                            10
                        ],
                        [
                            18,
                            14
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#1a1a1a"
            }
        },
        {
            "id": "tunnel_sec_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 11,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "secondary",
                    "tertiary"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            0.5
                        ],
                        [
                            12,
                            1
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            5
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#1a1a1a"
            }
        },
        {
            "id": "tunnel_pri_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 8,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "primary"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.8
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            13,
                            4
                        ],
                        [
                            14,
                            6
                        ],
                        [
                            15,
                            8
                        ],
                        [
                            16,
                            10
                        ],
                        [
                            17,
                            14
                        ],
                        [
                            18,
                            18
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            5,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": "#1a1a1a"
            }
        },
        {
            "id": "tunnel_trunk_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 5,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "trunk"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round",
                "visibility": "visible"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.8
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            13,
                            4
                        ],
                        [
                            14,
                            6
                        ],
                        [
                            15,
                            8
                        ],
                        [
                            16,
                            10
                        ],
                        [
                            17,
                            14
                        ],
                        [
                            18,
                            18
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            5,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": "#232323"
            }
        },
        {
            "id": "tunnel_mot_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 5,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "motorway"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.8
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            12,
                            4
                        ],
                        [
                            13,
                            5
                        ],
                        [
                            14,
                            7
                        ],
                        [
                            15,
                            9
                        ],
                        [
                            16,
                            11
                        ],
                        [
                            17,
                            13
                        ],
                        [
                            18,
                            22
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": "#232323"
            }
        },
        {
            "id": "tunnel_path",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "path"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            0.5
                        ],
                        [
                            16,
                            1
                        ],
                        [
                            18,
                            3
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#262626",
                "line-dasharray": {
                    "stops": [
                        [
                            15,
                            [
                                2,
                                2
                            ]
                        ],
                        [
                            18,
                            [
                                3,
                                3
                            ]
                        ]
                    ]
                }
            }
        },
        {
            "id": "tunnel_service_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "service"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            2
                        ],
                        [
                            16,
                            2
                        ],
                        [
                            17,
                            4
                        ],
                        [
                            18,
                            6
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#161616"
            }
        },
        {
            "id": "tunnel_minor_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "minor"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            3
                        ],
                        [
                            16,
                            4
                        ],
                        [
                            17,
                            8
                        ],
                        [
                            18,
                            12
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(22, 22, 22, 1)"
            }
        },
        {
            "id": "tunnel_sec_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 13,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "secondary",
                    "tertiary"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            2
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            3
                        ],
                        [
                            15,
                            4
                        ],
                        [
                            16,
                            6
                        ],
                        [
                            17,
                            10
                        ],
                        [
                            18,
                            14
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#161616"
            }
        },
        {
            "id": "tunnel_pri_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 11,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "primary"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            1
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(65, 71, 88, 1)"
            }
        },
        {
            "id": "tunnel_trunk_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 11,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "trunk"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round",
                "visibility": "visible"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            1
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#161616"
            }
        },
        {
            "id": "tunnel_mot_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 10,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "motorway"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            10,
                            1
                        ],
                        [
                            12,
                            2
                        ],
                        [
                            13,
                            3
                        ],
                        [
                            14,
                            5
                        ],
                        [
                            15,
                            7
                        ],
                        [
                            16,
                            9
                        ],
                        [
                            17,
                            11
                        ],
                        [
                            18,
                            20
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(65, 71, 88, 1)"
            }
        },
        {
            "id": "tunnel_rail",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 13,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "rail"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "visibility": "visible",
                "line-join": "round"
            },
            "paint": {
                "line-color": "#1a1a1a",
                "line-width": {
                    "base": 1.3,
                    "stops": [
                        [
                            13,
                            0.5
                        ],
                        [
                            14,
                            1
                        ],
                        [
                            15,
                            1
                        ],
                        [
                            16,
                            3
                        ],
                        [
                            21,
                            7
                        ]
                    ]
                },
                "line-opacity": 0.5
            }
        },
        {
            "id": "tunnel_rail_dash",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "rail"
                ],
                [
                    "==",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "visibility": "visible",
                "line-join": "round"
            },
            "paint": {
                "line-color": "#111",
                "line-width": {
                    "base": 1.3,
                    "stops": [
                        [
                            15,
                            0.5
                        ],
                        [
                            16,
                            1
                        ],
                        [
                            20,
                            5
                        ]
                    ]
                },
                "line-dasharray": {
                    "stops": [
                        [
                            15,
                            [
                                5,
                                5
                            ]
                        ],
                        [
                            16,
                            [
                                6,
                                6
                            ]
                        ]
                    ]
                },
                "line-opacity": 0.5
            }
        },
        {
            "id": "road_service_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "service"
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            1
                        ],
                        [
                            16,
                            3
                        ],
                        [
                            17,
                            6
                        ],
                        [
                            18,
                            8
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#1c1c1c"
            }
        },
        {
            "id": "road_minor_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 13,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "minor"
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            0.5
                        ],
                        [
                            12,
                            0.5
                        ],
                        [
                            14,
                            2
                        ],
                        [
                            15,
                            3
                        ],
                        [
                            16,
                            4.3
                        ],
                        [
                            17,
                            10
                        ],
                        [
                            18,
                            14
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": {
                    "stops": [
                        [
                            13,
                            "rgba(65, 71, 88, 1)"
                        ],
                        [
                            15.7,
                            "rgba(65, 71, 88, 1)"
                        ],
                        [
                            16,
                            "rgba(65, 71, 88, 1)"
                        ]
                    ]
                }
            }
        },
        {
            "id": "road_pri_case_ramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 12,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "primary"
                ],
                [
                    "==",
                    "ramp",
                    1
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            12,
                            2
                        ],
                        [
                            13,
                            3
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            5
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            10
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            5,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": "#232323"
            }
        },
        {
            "id": "road_trunk_case_ramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 12,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "trunk"
                ],
                [
                    "==",
                    "ramp",
                    1
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            12,
                            2
                        ],
                        [
                            13,
                            3
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            5
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            10
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": {
                    "stops": [
                        [
                            12,
                            "#1a1a1a"
                        ],
                        [
                            14,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "road_mot_case_ramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 12,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "motorway"
                ],
                [
                    "==",
                    "ramp",
                    1
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            12,
                            2
                        ],
                        [
                            13,
                            3
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            5
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            10
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": {
                    "stops": [
                        [
                            12,
                            "#1a1a1a"
                        ],
                        [
                            14,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "road_sec_case_noramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 11,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "secondary",
                    "tertiary"
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            0.9
                        ],
                        [
                            12,
                            1.5
                        ],
                        [
                            13,
                            3
                        ],
                        [
                            14,
                            5
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": {
                    "stops": [
                        [
                            11,
                            "rgba(65, 71, 88, 1)"
                        ],
                        [
                            12.99,
                            "rgba(65, 71, 88, 1)"
                        ],
                        [
                            13,
                            "rgba(65, 71, 88, 1)"
                        ]
                    ]
                }
            }
        },
        {
            "id": "road_pri_case_noramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 7,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "primary"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.8
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            13,
                            4
                        ],
                        [
                            14,
                            6
                        ],
                        [
                            15,
                            8
                        ],
                        [
                            16,
                            10
                        ],
                        [
                            17,
                            14
                        ],
                        [
                            18,
                            18
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            5,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": {
                    "stops": [
                        [
                            7,
                            "#1a1a1a"
                        ],
                        [
                            12,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "road_trunk_case_noramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 5,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "trunk"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.8
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            13,
                            4
                        ],
                        [
                            14,
                            6
                        ],
                        [
                            15,
                            8
                        ],
                        [
                            16,
                            10
                        ],
                        [
                            17,
                            14
                        ],
                        [
                            18,
                            18
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            5,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": {
                    "stops": [
                        [
                            5,
                            "#1a1a1a"
                        ],
                        [
                            12,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "road_mot_case_noramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 5,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "motorway"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.7
                        ],
                        [
                            8,
                            0.8
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            12,
                            4
                        ],
                        [
                            13,
                            5
                        ],
                        [
                            14,
                            7
                        ],
                        [
                            15,
                            9
                        ],
                        [
                            16,
                            11
                        ],
                        [
                            17,
                            13
                        ],
                        [
                            18,
                            22
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": {
                    "stops": [
                        [
                            5,
                            "#1a1a1a"
                        ],
                        [
                            12,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "road_path",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "path",
                    "track"
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            0.5
                        ],
                        [
                            16,
                            1
                        ],
                        [
                            18,
                            3
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#262626",
                "line-dasharray": {
                    "stops": [
                        [
                            15,
                            [
                                2,
                                2
                            ]
                        ],
                        [
                            18,
                            [
                                3,
                                3
                            ]
                        ]
                    ]
                }
            }
        },
        {
            "id": "road_service_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "service"
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            2
                        ],
                        [
                            16,
                            2
                        ],
                        [
                            17,
                            4
                        ],
                        [
                            18,
                            6
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#0b0b0b"
            }
        },
        {
            "id": "road_minor_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "minor"
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            3
                        ],
                        [
                            16,
                            4
                        ],
                        [
                            17,
                            8
                        ],
                        [
                            18,
                            12
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(65, 71, 88, 1)"
            }
        },
        {
            "id": "road_pri_fill_ramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 12,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "primary"
                ],
                [
                    "==",
                    "ramp",
                    1
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            12,
                            1
                        ],
                        [
                            13,
                            1.5
                        ],
                        [
                            14,
                            2
                        ],
                        [
                            15,
                            3
                        ],
                        [
                            16,
                            6
                        ],
                        [
                            17,
                            8
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#0b0b0b"
            }
        },
        {
            "id": "road_trunk_fill_ramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 12,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "trunk"
                ],
                [
                    "==",
                    "ramp",
                    1
                ]
            ],
            "layout": {
                "line-cap": "square",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            12,
                            1
                        ],
                        [
                            13,
                            1.5
                        ],
                        [
                            14,
                            2
                        ],
                        [
                            15,
                            3
                        ],
                        [
                            16,
                            6
                        ],
                        [
                            17,
                            8
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#0b0b0b"
            }
        },
        {
            "id": "road_mot_fill_ramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 12,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "motorway"
                ],
                [
                    "==",
                    "ramp",
                    1
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            12,
                            1
                        ],
                        [
                            13,
                            1.5
                        ],
                        [
                            14,
                            2
                        ],
                        [
                            15,
                            3
                        ],
                        [
                            16,
                            6
                        ],
                        [
                            17,
                            8
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(65, 71, 88, 1)"
            }
        },
        {
            "id": "road_sec_fill_noramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 13,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "secondary",
                    "tertiary"
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            2
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            3
                        ],
                        [
                            15,
                            4
                        ],
                        [
                            16,
                            6
                        ],
                        [
                            17,
                            10
                        ],
                        [
                            18,
                            14
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(65, 71, 88, 1)"
            }
        },
        {
            "id": "road_pri_fill_noramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 10,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "primary"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            10,
                            0.3
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(83, 86, 102, 1)"
            }
        },
        {
            "id": "road_trunk_fill_noramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 10,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "trunk"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            1
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(65, 71, 88, 1)"
            }
        },
        {
            "id": "road_mot_fill_noramp",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 10,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "motorway"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "!has",
                    "brunnel"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            10,
                            1
                        ],
                        [
                            12,
                            2
                        ],
                        [
                            13,
                            3
                        ],
                        [
                            14,
                            5
                        ],
                        [
                            15,
                            7
                        ],
                        [
                            16,
                            9
                        ],
                        [
                            17,
                            11
                        ],
                        [
                            18,
                            20
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(73, 73, 73, 1)"
            }
        },
        {
            "id": "rail",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 13,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "rail"
                ],
                [
                    "!=",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "visibility": "visible",
                "line-join": "round"
            },
            "paint": {
                "line-color": "#1a1a1a",
                "line-width": {
                    "base": 1.3,
                    "stops": [
                        [
                            13,
                            0.5
                        ],
                        [
                            14,
                            1
                        ],
                        [
                            15,
                            1
                        ],
                        [
                            16,
                            3
                        ],
                        [
                            21,
                            7
                        ]
                    ]
                }
            }
        },
        {
            "id": "rail_dash",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "rail"
                ],
                [
                    "!=",
                    "brunnel",
                    "tunnel"
                ]
            ],
            "layout": {
                "visibility": "visible",
                "line-join": "round"
            },
            "paint": {
                "line-color": "#111",
                "line-width": {
                    "base": 1.3,
                    "stops": [
                        [
                            15,
                            0.5
                        ],
                        [
                            16,
                            1
                        ],
                        [
                            20,
                            5
                        ]
                    ]
                },
                "line-dasharray": {
                    "stops": [
                        [
                            15,
                            [
                                5,
                                5
                            ]
                        ],
                        [
                            16,
                            [
                                6,
                                6
                            ]
                        ]
                    ]
                }
            }
        },
        {
            "id": "bridge_service_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "service"
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            1
                        ],
                        [
                            16,
                            3
                        ],
                        [
                            17,
                            6
                        ],
                        [
                            18,
                            8
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#1c1c1c"
            }
        },
        {
            "id": "bridge_minor_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 13,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "minor"
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "miter"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            0.5
                        ],
                        [
                            12,
                            0.5
                        ],
                        [
                            14,
                            2
                        ],
                        [
                            15,
                            3
                        ],
                        [
                            16,
                            4.3
                        ],
                        [
                            17,
                            10
                        ],
                        [
                            18,
                            14
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": {
                    "stops": [
                        [
                            13,
                            "#161616"
                        ],
                        [
                            15.7,
                            "#161616"
                        ],
                        [
                            16,
                            "#1c1c1c"
                        ]
                    ]
                }
            }
        },
        {
            "id": "bridge_sec_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 11,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "secondary",
                    "tertiary"
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "miter"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            0.5
                        ],
                        [
                            12,
                            1.5
                        ],
                        [
                            13,
                            3
                        ],
                        [
                            14,
                            5
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": {
                    "stops": [
                        [
                            11,
                            "#1a1a1a"
                        ],
                        [
                            12.99,
                            "#1a1a1a"
                        ],
                        [
                            13,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "bridge_pri_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 8,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "primary"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.8
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            13,
                            4
                        ],
                        [
                            14,
                            6
                        ],
                        [
                            15,
                            8
                        ],
                        [
                            16,
                            10
                        ],
                        [
                            17,
                            14
                        ],
                        [
                            18,
                            18
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            5,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": {
                    "stops": [
                        [
                            8,
                            "#1a1a1a"
                        ],
                        [
                            12,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "bridge_trunk_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 5,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "trunk"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round",
                "visibility": "visible"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.8
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            13,
                            4
                        ],
                        [
                            14,
                            6
                        ],
                        [
                            15,
                            8
                        ],
                        [
                            16,
                            10
                        ],
                        [
                            17,
                            14
                        ],
                        [
                            18,
                            18
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            5,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": {
                    "stops": [
                        [
                            5,
                            "#1a1a1a"
                        ],
                        [
                            12,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "bridge_mot_case",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 5,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "motorway"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            0.8
                        ],
                        [
                            8,
                            1
                        ],
                        [
                            11,
                            3
                        ],
                        [
                            12,
                            4
                        ],
                        [
                            13,
                            5
                        ],
                        [
                            14,
                            7
                        ],
                        [
                            15,
                            9
                        ],
                        [
                            16,
                            11
                        ],
                        [
                            17,
                            13
                        ],
                        [
                            18,
                            22
                        ]
                    ]
                },
                "line-opacity": {
                    "stops": [
                        [
                            6,
                            0.5
                        ],
                        [
                            7,
                            1
                        ]
                    ]
                },
                "line-color": {
                    "stops": [
                        [
                            5,
                            "#1a1a1a"
                        ],
                        [
                            10,
                            "#232323"
                        ]
                    ]
                }
            }
        },
        {
            "id": "bridge_path",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "path"
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            0.5
                        ],
                        [
                            16,
                            1
                        ],
                        [
                            18,
                            3
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#262626",
                "line-dasharray": {
                    "stops": [
                        [
                            15,
                            [
                                2,
                                2
                            ]
                        ],
                        [
                            18,
                            [
                                3,
                                3
                            ]
                        ]
                    ]
                }
            }
        },
        {
            "id": "bridge_service_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "service"
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            2
                        ],
                        [
                            16,
                            2
                        ],
                        [
                            17,
                            4
                        ],
                        [
                            18,
                            6
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#0b0b0b"
            }
        },
        {
            "id": "bridge_minor_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 15,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "minor"
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            15,
                            3
                        ],
                        [
                            16,
                            4
                        ],
                        [
                            17,
                            8
                        ],
                        [
                            18,
                            12
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#0b0b0b"
            }
        },
        {
            "id": "bridge_sec_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 13,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "secondary",
                    "tertiary"
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            2
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            3
                        ],
                        [
                            15,
                            4
                        ],
                        [
                            16,
                            6
                        ],
                        [
                            17,
                            10
                        ],
                        [
                            18,
                            14
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#0b0b0b"
            }
        },
        {
            "id": "bridge_pri_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 11,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "primary"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            1
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "#0b0b0b"
            }
        },
        {
            "id": "bridge_trunk_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 11,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "trunk"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round",
                "visibility": "visible"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            11,
                            1
                        ],
                        [
                            13,
                            2
                        ],
                        [
                            14,
                            4
                        ],
                        [
                            15,
                            6
                        ],
                        [
                            16,
                            8
                        ],
                        [
                            17,
                            12
                        ],
                        [
                            18,
                            16
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(65, 71, 88, 1)"
            }
        },
        {
            "id": "bridge_mot_fill",
            "type": "line",
            "source": "carto",
            "source-layer": "transportation",
            "minzoom": 10,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "motorway"
                ],
                [
                    "!=",
                    "ramp",
                    1
                ],
                [
                    "==",
                    "brunnel",
                    "bridge"
                ]
            ],
            "layout": {
                "line-cap": "butt",
                "line-join": "round"
            },
            "paint": {
                "line-width": {
                    "stops": [
                        [
                            10,
                            1
                        ],
                        [
                            12,
                            2
                        ],
                        [
                            13,
                            3
                        ],
                        [
                            14,
                            5
                        ],
                        [
                            15,
                            7
                        ],
                        [
                            16,
                            9
                        ],
                        [
                            17,
                            11
                        ],
                        [
                            18,
                            20
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-color": "rgba(65, 71, 88, 1)"
            }
        },
        {
            "id": "building",
            "type": "fill",
            "source": "carto",
            "source-layer": "building",
            "layout": {
                "visibility": "visible"
            },
            "paint": {
                "fill-color": {
                    "base": 1,
                    "stops": [
                        [
                            15.5,
                            "transparent"
                        ],
                        [
                            16,
                            "transparent"
                        ]
                    ]
                },
                "fill-antialias": true
            }
        },
        {
            "id": "building-top",
            "type": "fill",
            "source": "carto",
            "source-layer": "building",
            "layout": {
                "visibility": "visible"
            },
            "paint": {
                "fill-translate": {
                    "base": 1,
                    "stops": [
                        [
                            14,
                            [
                                0,
                                0
                            ]
                        ],
                        [
                            16,
                            [
                                -2,
                                -2
                            ]
                        ]
                    ]
                },
                "fill-outline-color": "#0e0e0e",
                "fill-color": "rgba(57, 57, 57, 1)",
                "fill-opacity": {
                    "base": 1,
                    "stops": [
                        [
                            13,
                            0
                        ],
                        [
                            16,
                            1
                        ]
                    ]
                }
            }
        },
        {
            "id": "boundary_country_outline",
            "type": "line",
            "source": "carto",
            "source-layer": "boundary",
            "minzoom": 6,
            "maxzoom": 24,
            "filter": [
                "all",
                [
                    "==",
                    "admin_level",
                    2
                ],
                [
                    "==",
                    "maritime",
                    0
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-color": "#2C353C",
                "line-opacity": 0.5,
                "line-width": 8,
                "line-offset": 0
            }
        },
        {
            "id": "boundary_country_inner",
            "type": "line",
            "source": "carto",
            "source-layer": "boundary",
            "minzoom": 0,
            "filter": [
                "all",
                [
                    "==",
                    "admin_level",
                    2
                ],
                [
                    "==",
                    "maritime",
                    0
                ]
            ],
            "layout": {
                "line-cap": "round",
                "line-join": "round"
            },
            "paint": {
                "line-color": {
                    "stops": [
                        [
                            4,
                            "rgba(92, 94, 94, 1)"
                        ],
                        [
                            5,
                            "rgba(96, 96, 96, 1)"
                        ],
                        [
                            6,
                            "rgba(102, 102, 102, 1)"
                        ]
                    ]
                },
                "line-opacity": 1,
                "line-width": {
                    "stops": [
                        [
                            3,
                            1
                        ],
                        [
                            6,
                            1.5
                        ]
                    ]
                },
                "line-offset": 0
            }
        },
        {
            "id": "waterway_label",
            "type": "symbol",
            "source": "carto",
            "source-layer": "waterway",
            "filter": [
                "all",
                [
                    "has",
                    "name"
                ],
                [
                    "==",
                    "class",
                    "river"
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Regular Italic",
                    "Open Sans Italic",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "symbol-placement": "line",
                "symbol-spacing": 300,
                "symbol-avoid-edges": false,
                "text-size": {
                    "stops": [
                        [
                            9,
                            8
                        ],
                        [
                            10,
                            9
                        ]
                    ]
                },
                "text-padding": 2,
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto",
                "text-offset": {
                    "stops": [
                        [
                            6,
                            [
                                0,
                                -0.2
                            ]
                        ],
                        [
                            11,
                            [
                                0,
                                -0.4
                            ]
                        ],
                        [
                            12,
                            [
                                0,
                                -0.6
                            ]
                        ]
                    ]
                },
                "text-letter-spacing": 0,
                "text-keep-upright": true
            },
            "paint": {
                "text-color": "rgba(164, 164, 164, 1)",
                "text-halo-color": "#181818",
                "text-halo-width": 1
            }
        },
        {
            "id": "watername_ocean",
            "type": "symbol",
            "source": "carto",
            "source-layer": "water_name",
            "minzoom": 0,
            "maxzoom": 5,
            "filter": [
                "all",
                [
                    "has",
                    "name"
                ],
                [
                    "==",
                    "$type",
                    "Point"
                ],
                [
                    "==",
                    "class",
                    "ocean"
                ]
            ],
            "layout": {
                "text-field": "{name}",
                "symbol-placement": "point",
                "text-size": {
                    "stops": [
                        [
                            0,
                            13
                        ],
                        [
                            2,
                            14
                        ],
                        [
                            4,
                            18
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Medium Italic",
                    "Open Sans Italic",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-line-height": 1.2,
                "text-padding": 2,
                "text-allow-overlap": false,
                "text-ignore-placement": false,
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto",
                "text-max-width": 6,
                "text-letter-spacing": 0.1
            },
            "paint": {
                "text-color": "rgba(109, 123, 129, 1)",
                "text-halo-color": "rgba(0,0,0,0.7)",
                "text-halo-width": 1,
                "text-halo-blur": 0
            }
        },
        {
            "id": "watername_sea",
            "type": "symbol",
            "source": "carto",
            "source-layer": "water_name",
            "minzoom": 5,
            "filter": [
                "all",
                [
                    "has",
                    "name"
                ],
                [
                    "==",
                    "$type",
                    "Point"
                ],
                [
                    "==",
                    "class",
                    "sea"
                ]
            ],
            "layout": {
                "text-field": "{name}",
                "symbol-placement": "point",
                "text-size": 12,
                "text-font": [
                    "Montserrat Medium Italic",
                    "Open Sans Italic",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-line-height": 1.2,
                "text-padding": 2,
                "text-allow-overlap": false,
                "text-ignore-placement": false,
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto",
                "text-max-width": 6,
                "text-letter-spacing": 0.1
            },
            "paint": {
                "text-color": "#3c3c3c",
                "text-halo-color": "rgba(0,0,0,0.7)",
                "text-halo-width": 1,
                "text-halo-blur": 0
            }
        },
        {
            "id": "watername_lake",
            "type": "symbol",
            "source": "carto",
            "source-layer": "water_name",
            "minzoom": 4,
            "filter": [
                "all",
                [
                    "has",
                    "name"
                ],
                [
                    "==",
                    "$type",
                    "Point"
                ],
                [
                    "==",
                    "class",
                    "lake"
                ]
            ],
            "layout": {
                "text-field": {
                    "stops": [
                        [
                            8,
                            "{name_en}"
                        ],
                        [
                            13,
                            "{name}"
                        ]
                    ]
                },
                "symbol-placement": "point",
                "text-size": {
                    "stops": [
                        [
                            13,
                            9
                        ],
                        [
                            14,
                            10
                        ],
                        [
                            15,
                            11
                        ],
                        [
                            16,
                            12
                        ],
                        [
                            17,
                            13
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Regular Italic",
                    "Open Sans Italic",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-line-height": 1.2,
                "text-padding": 2,
                "text-allow-overlap": false,
                "text-ignore-placement": false,
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto"
            },
            "paint": {
                "text-color": "rgba(155, 155, 155, 1)",
                "text-halo-color": "#181818",
                "text-halo-width": 1,
                "text-halo-blur": 1
            }
        },
        {
            "id": "watername_lake_line",
            "type": "symbol",
            "source": "carto",
            "source-layer": "water_name",
            "filter": [
                "all",
                [
                    "has",
                    "name"
                ],
                [
                    "==",
                    "$type",
                    "LineString"
                ]
            ],
            "layout": {
                "text-field": {
                    "stops": [
                        [
                            8,
                            "{name_en}"
                        ],
                        [
                            13,
                            "{name}"
                        ]
                    ]
                },
                "symbol-placement": "line",
                "text-size": {
                    "stops": [
                        [
                            13,
                            9
                        ],
                        [
                            14,
                            10
                        ],
                        [
                            15,
                            11
                        ],
                        [
                            16,
                            12
                        ],
                        [
                            17,
                            13
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Regular Italic",
                    "Open Sans Italic",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "symbol-spacing": 350,
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto",
                "text-line-height": 1.2
            },
            "paint": {
                "text-color": "#444",
                "text-halo-color": "#181818",
                "text-halo-width": 1,
                "text-halo-blur": 1
            }
        },
        {
            "id": "place_hamlet",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 12,
            "maxzoom": 16,
            "filter": [
                "any",
                [
                    "==",
                    "class",
                    "neighbourhood"
                ],
                [
                    "==",
                    "class",
                    "hamlet"
                ]
            ],
            "layout": {
                "text-field": {
                    "stops": [
                        [
                            8,
                            "{name_en}"
                        ],
                        [
                            14,
                            "{name}"
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Regular",
                    "Open Sans Regular",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            13,
                            8
                        ],
                        [
                            14,
                            10
                        ],
                        [
                            16,
                            11
                        ]
                    ]
                },
                "icon-image": "",
                "icon-offset": [
                    16,
                    0
                ],
                "text-anchor": "center",
                "icon-size": 1,
                "text-max-width": 10,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ],
                "text-transform": {
                    "stops": [
                        [
                            12,
                            "none"
                        ],
                        [
                            14,
                            "uppercase"
                        ]
                    ]
                }
            },
            "paint": {
                "text-color": "rgba(182, 180, 180, 1)",
                "icon-color": "#666",
                "icon-translate-anchor": "map",
                "text-halo-color": "rgba(53, 52, 52, 1)",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_suburbs",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 12,
            "maxzoom": 16,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "suburb"
                ]
            ],
            "layout": {
                "text-field": {
                    "stops": [
                        [
                            8,
                            "{name_en}"
                        ],
                        [
                            13,
                            "{name}"
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Regular",
                    "Open Sans Regular",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            12,
                            9
                        ],
                        [
                            13,
                            10
                        ],
                        [
                            14,
                            11
                        ],
                        [
                            15,
                            12
                        ],
                        [
                            16,
                            13
                        ]
                    ]
                },
                "icon-image": "",
                "icon-offset": [
                    16,
                    0
                ],
                "text-anchor": "center",
                "icon-size": 1,
                "text-max-width": 10,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ],
                "text-transform": {
                    "stops": [
                        [
                            8,
                            "none"
                        ],
                        [
                            12,
                            "uppercase"
                        ]
                    ]
                }
            },
            "paint": {
                "text-color": "#666",
                "icon-color": "#666",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_villages",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 10,
            "maxzoom": 16,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "village"
                ]
            ],
            "layout": {
                "text-field": {
                    "stops": [
                        [
                            8,
                            "{name_en}"
                        ],
                        [
                            13,
                            "{name}"
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            10,
                            9
                        ],
                        [
                            12,
                            10
                        ],
                        [
                            13,
                            11
                        ],
                        [
                            14,
                            12
                        ],
                        [
                            16,
                            13
                        ]
                    ]
                },
                "icon-image": "",
                "icon-offset": [
                    16,
                    0
                ],
                "text-anchor": "center",
                "icon-size": 1,
                "text-max-width": 10,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ],
                "text-transform": "none"
            },
            "paint": {
                "text-color": "rgba(154, 153, 153, 1)",
                "icon-color": "#666",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_town",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 8,
            "maxzoom": 14,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "town"
                ]
            ],
            "layout": {
                "text-field": {
                    "stops": [
                        [
                            8,
                            "{name_en}"
                        ],
                        [
                            13,
                            "{name}"
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            8,
                            10
                        ],
                        [
                            9,
                            10
                        ],
                        [
                            10,
                            11
                        ],
                        [
                            13,
                            14
                        ],
                        [
                            14,
                            15
                        ]
                    ]
                },
                "icon-image": "",
                "icon-offset": [
                    16,
                    0
                ],
                "text-anchor": "center",
                "icon-size": 1,
                "text-max-width": 10,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ],
                "text-transform": "none"
            },
            "paint": {
                "text-color": "rgba(204, 208, 228, 1)",
                "icon-color": "#666",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_country_2",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 3,
            "maxzoom": 10,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "country"
                ],
                [
                    ">=",
                    "rank",
                    3
                ],
                [
                    "has",
                    "iso_a2"
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            3,
                            10
                        ],
                        [
                            5,
                            11
                        ],
                        [
                            6,
                            12
                        ],
                        [
                            7,
                            13
                        ],
                        [
                            8,
                            14
                        ]
                    ]
                },
                "text-transform": "uppercase"
            },
            "paint": {
                "text-color": {
                    "stops": [
                        [
                            3,
                            "rgba(157, 157, 157, 1)"
                        ],
                        [
                            5,
                            "rgba(114, 114, 114, 1)"
                        ],
                        [
                            6,
                            "rgba(112, 112, 112, 1)"
                        ]
                    ]
                },
                "text-halo-color": "#111",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_country_1",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 2,
            "maxzoom": 7,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "country"
                ],
                [
                    "<=",
                    "rank",
                    2
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            3,
                            11
                        ],
                        [
                            4,
                            12
                        ],
                        [
                            5,
                            13
                        ],
                        [
                            6,
                            14
                        ]
                    ]
                },
                "text-transform": "uppercase",
                "text-max-width": {
                    "stops": [
                        [
                            2,
                            6
                        ],
                        [
                            3,
                            6
                        ],
                        [
                            4,
                            9
                        ],
                        [
                            5,
                            12
                        ]
                    ]
                }
            },
            "paint": {
                "text-color": {
                    "stops": [
                        [
                            3,
                            "rgba(158, 182, 189, 1)"
                        ],
                        [
                            5,
                            "rgba(118, 126, 137, 1)"
                        ],
                        [
                            6,
                            "rgba(120, 141, 147, 1)"
                        ]
                    ]
                },
                "text-halo-color": "#111",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_state",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 5,
            "maxzoom": 10,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "state"
                ],
                [
                    "<=",
                    "rank",
                    4
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            5,
                            12
                        ],
                        [
                            7,
                            14
                        ]
                    ]
                },
                "text-transform": "uppercase",
                "text-max-width": 9
            },
            "paint": {
                "text-color": "rgba(203, 230, 230, 1)",
                "text-halo-color": "#111",
                "text-halo-width": 0
            }
        },
        {
            "id": "place_continent",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 0,
            "maxzoom": 2,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "continent"
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-transform": "uppercase",
                "text-size": 14,
                "text-letter-spacing": 0.1,
                "text-max-width": 9,
                "text-justify": "center",
                "text-keep-upright": false
            },
            "paint": {
                "text-color": "rgba(135, 164, 179, 1)",
                "text-halo-color": "#111",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_city_r6",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 8,
            "maxzoom": 15,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "city"
                ],
                [
                    ">=",
                    "rank",
                    6
                ]
            ],
            "layout": {
                "text-field": {
                    "stops": [
                        [
                            8,
                            "{name_en}"
                        ],
                        [
                            13,
                            "{name}"
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            8,
                            12
                        ],
                        [
                            9,
                            13
                        ],
                        [
                            10,
                            14
                        ],
                        [
                            13,
                            17
                        ],
                        [
                            14,
                            20
                        ]
                    ]
                },
                "icon-image": "",
                "icon-offset": [
                    16,
                    0
                ],
                "text-anchor": "center",
                "icon-size": 1,
                "text-max-width": 10,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ],
                "text-transform": "uppercase"
            },
            "paint": {
                "text-color": "rgba(168, 176, 180, 1)",
                "icon-color": "#666",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_city_r5",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 8,
            "maxzoom": 15,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "city"
                ],
                [
                    ">=",
                    "rank",
                    0
                ],
                [
                    "<=",
                    "rank",
                    5
                ]
            ],
            "layout": {
                "text-field": {
                    "stops": [
                        [
                            8,
                            "{name_en}"
                        ],
                        [
                            13,
                            "{name}"
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            8,
                            14
                        ],
                        [
                            10,
                            16
                        ],
                        [
                            13,
                            19
                        ],
                        [
                            14,
                            22
                        ]
                    ]
                },
                "icon-image": "",
                "icon-offset": [
                    16,
                    0
                ],
                "text-anchor": "center",
                "icon-size": 1,
                "text-max-width": 10,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ],
                "text-transform": "uppercase"
            },
            "paint": {
                "text-color": "rgba(211, 228, 236, 1)",
                "icon-color": "#666",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_city_dot_r7",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 6,
            "maxzoom": 7,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "city"
                ],
                [
                    "<=",
                    "rank",
                    7
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": 12,
                "icon-image": "circle-11",
                "icon-offset": [
                    16,
                    5
                ],
                "text-anchor": "right",
                "icon-size": 0.4,
                "text-max-width": 8,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ]
            },
            "paint": {
                "text-color": "rgba(174, 191, 207, 1)",
                "icon-color": "rgba(94, 105, 106, 1)",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_city_dot_r4",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 5,
            "maxzoom": 7,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "city"
                ],
                [
                    "<=",
                    "rank",
                    4
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": 12,
                "icon-image": "circle-11",
                "icon-offset": [
                    16,
                    5
                ],
                "text-anchor": "right",
                "icon-size": 0.4,
                "text-max-width": 8,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ]
            },
            "paint": {
                "text-color": "rgba(233, 239, 246, 1)",
                "icon-color": "#666",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_city_dot_r2",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 4,
            "maxzoom": 7,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "city"
                ],
                [
                    "<=",
                    "rank",
                    2
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": 12,
                "icon-image": "circle-11",
                "icon-offset": [
                    16,
                    5
                ],
                "text-anchor": "right",
                "icon-size": 0.4,
                "text-max-width": 8,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ]
            },
            "paint": {
                "text-color": "rgba(175, 194, 217, 1)",
                "icon-color": "rgba(131, 164, 189, 1)",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_city_dot_z7",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 7,
            "maxzoom": 8,
            "filter": [
                "all",
                [
                    "!has",
                    "capital"
                ],
                [
                    "!in",
                    "class",
                    "country",
                    "state"
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": 12,
                "icon-image": "circle-11",
                "icon-offset": [
                    16,
                    5
                ],
                "text-anchor": "right",
                "icon-size": 0.4,
                "text-max-width": 8,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ]
            },
            "paint": {
                "text-color": "rgba(160, 179, 191, 1)",
                "icon-color": "rgba(113, 128, 147, 1)",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "place_capital_dot_z7",
            "type": "symbol",
            "source": "carto",
            "source-layer": "place",
            "minzoom": 7,
            "maxzoom": 8,
            "filter": [
                "all",
                [
                    ">",
                    "capital",
                    0
                ]
            ],
            "layout": {
                "text-field": "{name_en}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": 12,
                "icon-image": "circle-11",
                "icon-offset": [
                    16,
                    5
                ],
                "text-anchor": "right",
                "icon-size": 0.4,
                "text-max-width": 8,
                "text-keep-upright": true,
                "text-offset": [
                    0.2,
                    0.2
                ],
                "text-transform": "uppercase"
            },
            "paint": {
                "text-color": "rgba(177, 201, 214, 1)",
                "icon-color": "#666",
                "icon-translate-anchor": "map",
                "text-halo-color": "#222",
                "text-halo-width": 1
            }
        },
        {
            "id": "poi_stadium",
            "type": "symbol",
            "source": "carto",
            "source-layer": "poi",
            "minzoom": 15,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "stadium",
                    "cemetery",
                    "attraction"
                ],
                [
                    "<=",
                    "rank",
                    3
                ]
            ],
            "layout": {
                "text-field": "{name}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            15,
                            8
                        ],
                        [
                            17,
                            9
                        ],
                        [
                            18,
                            10
                        ]
                    ]
                },
                "text-transform": "uppercase"
            },
            "paint": {
                "text-color": "#515151",
                "text-halo-color": "#151515",
                "text-halo-width": 1
            }
        },
        {
            "id": "poi_park",
            "type": "symbol",
            "source": "carto",
            "source-layer": "poi",
            "minzoom": 15,
            "filter": [
                "all",
                [
                    "==",
                    "class",
                    "park"
                ]
            ],
            "layout": {
                "text-field": "{name}",
                "text-font": [
                    "Montserrat Medium",
                    "Open Sans Bold",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            15,
                            8
                        ],
                        [
                            17,
                            9
                        ],
                        [
                            18,
                            10
                        ]
                    ]
                },
                "text-transform": "uppercase"
            },
            "paint": {
                "text-color": "#515151",
                "text-halo-color": "#151515",
                "text-halo-width": 1
            }
        },
        {
            "id": "roadname_minor",
            "type": "symbol",
            "source": "carto",
            "source-layer": "transportation_name",
            "minzoom": 16,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "minor",
                    "service"
                ]
            ],
            "layout": {
                "symbol-placement": "line",
                "text-font": [
                    "Montserrat Regular",
                    "Open Sans Regular",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": 9,
                "text-field": "{name}",
                "symbol-avoid-edges": false,
                "symbol-spacing": 200,
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto",
                "text-justify": "center"
            },
            "paint": {
                "text-color": "rgba(181, 180, 180, 1)",
                "text-halo-color": "#111",
                "text-halo-width": 1
            }
        },
        {
            "id": "roadname_sec",
            "type": "symbol",
            "source": "carto",
            "source-layer": "transportation_name",
            "minzoom": 15,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "secondary",
                    "tertiary"
                ]
            ],
            "layout": {
                "symbol-placement": "line",
                "text-font": [
                    "Montserrat Regular",
                    "Open Sans Regular",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            15,
                            9
                        ],
                        [
                            16,
                            11
                        ],
                        [
                            18,
                            12
                        ]
                    ]
                },
                "text-field": "{name}",
                "symbol-avoid-edges": false,
                "symbol-spacing": 200,
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto",
                "text-justify": "center"
            },
            "paint": {
                "text-color": "rgba(146, 146, 146, 1)",
                "text-halo-color": "rgba(34, 34, 34, 1)",
                "text-halo-width": 1
            }
        },
        {
            "id": "roadname_pri",
            "type": "symbol",
            "source": "carto",
            "source-layer": "transportation_name",
            "minzoom": 14,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "primary"
                ]
            ],
            "layout": {
                "symbol-placement": "line",
                "text-font": [
                    "Montserrat Regular",
                    "Open Sans Regular",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            14,
                            10
                        ],
                        [
                            15,
                            10
                        ],
                        [
                            16,
                            11
                        ],
                        [
                            18,
                            12
                        ]
                    ]
                },
                "text-field": "{name}",
                "symbol-avoid-edges": false,
                "symbol-spacing": {
                    "stops": [
                        [
                            6,
                            200
                        ],
                        [
                            16,
                            250
                        ]
                    ]
                },
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto",
                "text-justify": "center",
                "text-letter-spacing": {
                    "stops": [
                        [
                            14,
                            0
                        ],
                        [
                            16,
                            0.2
                        ]
                    ]
                }
            },
            "paint": {
                "text-color": "rgba(189, 189, 189, 1)",
                "text-halo-color": "#111",
                "text-halo-width": 1
            }
        },
        {
            "id": "roadname_major",
            "type": "symbol",
            "source": "carto",
            "source-layer": "transportation_name",
            "minzoom": 13,
            "filter": [
                "all",
                [
                    "in",
                    "class",
                    "trunk",
                    "motorway"
                ]
            ],
            "layout": {
                "symbol-placement": "line",
                "text-font": [
                    "Montserrat Regular",
                    "Open Sans Regular",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ],
                "text-size": {
                    "stops": [
                        [
                            14,
                            10
                        ],
                        [
                            15,
                            10
                        ],
                        [
                            16,
                            11
                        ],
                        [
                            18,
                            12
                        ]
                    ]
                },
                "text-field": "{name}",
                "symbol-avoid-edges": false,
                "symbol-spacing": {
                    "stops": [
                        [
                            6,
                            200
                        ],
                        [
                            16,
                            250
                        ]
                    ]
                },
                "text-pitch-alignment": "auto",
                "text-rotation-alignment": "auto",
                "text-justify": "center",
                "text-letter-spacing": {
                    "stops": [
                        [
                            13,
                            0
                        ],
                        [
                            16,
                            0.2
                        ]
                    ]
                }
            },
            "paint": {
                "text-color": "#383838",
                "text-halo-color": "#111",
                "text-halo-width": 1
            }
        },
        {
            "id": "housenumber",
            "type": "symbol",
            "source": "carto",
            "source-layer": "housenumber",
            "minzoom": 17,
            "maxzoom": 24,
            "layout": {
                "text-field": "{housenumber}",
                "text-size": {
                    "stops": [
                        [
                            17,
                            9
                        ],
                        [
                            18,
                            11
                        ]
                    ]
                },
                "text-font": [
                    "Montserrat Regular",
                    "Open Sans Regular",
                    "Noto Sans Regular",
                    "HanWangHeiLight Regular",
                    "NanumBarunGothic Regular"
                ]
            },
            "paint": {
                "text-halo-color": "transparent",
                "text-color": "transparent",
                "text-halo-width": 0.75
            }
        }
    ],
    "id": "voyager",
    "owner": "Carto"
}

window.mapStyles["arcgishybrid"] = {
  "version": 8,
  "name": "ArcGIS Hybrid",
  "metadata": {},
  "center": [
    1.537786,
    41.837539
  ],
  "zoom": 12,
  "bearing": 0,
  "pitch": 0,
  "light": {
    "anchor": "viewport",
    "color": "white",
    "intensity": 0.4,
    "position": [
      1.15,
      45,
      30
    ]
  },
  "sources": {
    "ortoEsri": {
      "type": "raster",
      "tiles": [
        "https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}"
      ],
      "tileSize": 256,
      "maxzoom": 18,
      "attribution": "ESRI &copy; <a href='http://www.esri.com'>ESRI</a>"
    },
    "ortoInstaMaps": {
      "type": "raster",
      "tiles": [
        "https://tilemaps.icgc.cat/mapfactory/wmts/orto_8_12/CAT3857/{z}/{x}/{y}.png"
      ],
      "tileSize": 256,
      "maxzoom": 13
    },
    "ortoICGC": {
      "type": "raster",
      "tiles": [
        "https://geoserveis.icgc.cat/icc_mapesmultibase/noutm/wmts/orto/GRID3857/{z}/{x}/{y}.jpeg"
      ],
      "tileSize": 256,
      "minzoom": 13.1,
      "maxzoom": 20
    },
    "openmaptiles": {
      "type": "vector",
      "url": "https://geoserveis.icgc.cat/contextmaps/basemap.json"
    }
  },
  "sprite": "https://geoserveis.icgc.cat/contextmaps/sprites/sprite@1",
  "glyphs": "https://geoserveis.icgc.cat/contextmaps/glyphs/{fontstack}/{range}.pbf",
  "layers": [
    {
      "id": "background",
      "type": "background",
      "paint": {
        "background-color": "#F4F9F4"
      }
    },
    {
      "id": "ortoEsri",
      "type": "raster",
      "source": "ortoEsri",
      "maxzoom": 16,
      "layout": {
        "visibility": "visible"
      }
    },
    {
      "id": "ortoICGC",
      "type": "raster",
      "source": "ortoICGC",
      "minzoom": 13.1,
      "maxzoom": 19,
      "layout": {
        "visibility": "visible"
      }
    },
    {
      "id": "ortoInstaMaps",
      "type": "raster",
      "source": "ortoInstaMaps",
      "maxzoom": 13,
      "layout": {
        "visibility": "visible"
      }
    },
    {
      "id": "waterway_tunnel",
      "type": "line",
      "source": "openmaptiles",
      "source-layer": "waterway",
      "minzoom": 14,
      "filter": [
        "all",
        [
          "in",
          "class",
          "river",
          "stream",
          "canal"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round"
      },
      "paint": {
        "line-color": "#a0c8f0",
        "line-width": {
          "base": 1.3,
          "stops": [
            [
              13,
              0.5
            ],
            [
              20,
              6
            ]
          ]
        },
        "line-dasharray": [
          2,
          4
        ]
      }
    },
    {
      "id": "waterway-other",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849382550.77"
      },
      "source": "openmaptiles",
      "source-layer": "waterway",
      "filter": [
        "!in",
        "class",
        "canal",
        "river",
        "stream"
      ],
      "layout": {
        "line-cap": "round"
      },
      "paint": {
        "line-color": "#a0c8f0",
        "line-width": {
          "base": 1.3,
          "stops": [
            [
              13,
              0.5
            ],
            [
              20,
              2
            ]
          ]
        }
      }
    },
    {
      "id": "waterway-stream-canal",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849382550.77"
      },
      "source": "openmaptiles",
      "source-layer": "waterway",
      "filter": [
        "all",
        [
          "in",
          "class",
          "canal",
          "stream"
        ],
        [
          "!=",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round"
      },
      "paint": {
        "line-color": "#a0c8f0",
        "line-width": {
          "base": 1.3,
          "stops": [
            [
              13,
              0.5
            ],
            [
              20,
              6
            ]
          ]
        }
      }
    },
    {
      "id": "waterway-river",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849382550.77"
      },
      "source": "openmaptiles",
      "source-layer": "waterway",
      "filter": [
        "all",
        [
          "==",
          "class",
          "river"
        ],
        [
          "!=",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round"
      },
      "paint": {
        "line-color": "#a0c8f0",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              10,
              0.8
            ],
            [
              20,
              4
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "water-offset",
      "type": "fill",
      "metadata": {
        "mapbox:group": "1444849382550.77"
      },
      "source": "openmaptiles",
      "source-layer": "water",
      "maxzoom": 8,
      "filter": [
        "==",
        "$type",
        "Polygon"
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-opacity": 0,
        "fill-color": "#a0c8f0",
        "fill-translate": {
          "base": 1,
          "stops": [
            [
              6,
              [
                2,
                0
              ]
            ],
            [
              8,
              [
                0,
                0
              ]
            ]
          ]
        }
      }
    },
    {
      "id": "water",
      "type": "fill",
      "metadata": {
        "mapbox:group": "1444849382550.77"
      },
      "source": "openmaptiles",
      "source-layer": "water",
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-color": "hsl(210, 67%, 85%)",
        "fill-opacity": 0
      }
    },
    {
      "id": "water-pattern",
      "type": "fill",
      "metadata": {
        "mapbox:group": "1444849382550.77"
      },
      "source": "openmaptiles",
      "source-layer": "water",
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-translate": [
          0,
          2.5
        ],
        "fill-pattern": "wave",
        "fill-opacity": 1
      }
    },
    {
      "id": "landcover-ice-shelf",
      "type": "fill",
      "metadata": {
        "mapbox:group": "1444849382550.77"
      },
      "source": "openmaptiles",
      "source-layer": "landcover",
      "filter": [
        "==",
        "subclass",
        "ice_shelf"
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-color": "#fff",
        "fill-opacity": {
          "base": 1,
          "stops": [
            [
              0,
              0.9
            ],
            [
              10,
              0.3
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel-service-track-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "in",
          "class",
          "service",
          "track"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#cfcdca",
        "line-dasharray": [
          0.5,
          0.25
        ],
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              15,
              1
            ],
            [
              16,
              4
            ],
            [
              20,
              11
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel-minor-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "==",
          "class",
          "minor"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#cfcdca",
        "line-opacity": {
          "stops": [
            [
              12,
              0
            ],
            [
              12.5,
              1
            ]
          ]
        },
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12,
              0.5
            ],
            [
              13,
              1
            ],
            [
              14,
              4
            ],
            [
              20,
              15
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel-secondary-tertiary-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": 1,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              8,
              1.5
            ],
            [
              20,
              17
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel-trunk-primary-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "in",
          "class",
          "primary",
          "trunk"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              5,
              0.4
            ],
            [
              6,
              0.6
            ],
            [
              7,
              1.5
            ],
            [
              20,
              22
            ]
          ]
        },
        "line-opacity": 0.7
      }
    },
    {
      "id": "tunnel-motorway-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "==",
          "class",
          "motorway"
        ]
      ],
      "layout": {
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-dasharray": [
          0.5,
          0.25
        ],
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              5,
              0.4
            ],
            [
              6,
              0.6
            ],
            [
              7,
              1.5
            ],
            [
              20,
              22
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "tunnel-path",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "==",
            "brunnel",
            "tunnel"
          ],
          [
            "==",
            "class",
            "path"
          ]
        ]
      ],
      "paint": {
        "line-color": "#cba",
        "line-dasharray": [
          1.5,
          0.75
        ],
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              15,
              1.2
            ],
            [
              20,
              4
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel-service-track",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "in",
          "class",
          "service",
          "track"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fff",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              15.5,
              0
            ],
            [
              16,
              2
            ],
            [
              20,
              7.5
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel-minor",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "==",
          "class",
          "minor_road"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fff",
        "line-opacity": 1,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              13.5,
              0
            ],
            [
              14,
              2.5
            ],
            [
              20,
              11.5
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel-secondary-tertiary",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fff4c6",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              7,
              0.5
            ],
            [
              20,
              10
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel-trunk-primary",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "in",
          "class",
          "primary",
          "trunk"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fff4c6",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              7,
              0.5
            ],
            [
              20,
              18
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "tunnel-motorway",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "==",
          "class",
          "motorway"
        ]
      ],
      "layout": {
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#ffdaa6",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              7,
              0.5
            ],
            [
              20,
              18
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "tunnel-railway",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849354174.1904"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "tunnel"
        ],
        [
          "==",
          "class",
          "rail"
        ]
      ],
      "paint": {
        "line-color": "#bbb",
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14,
              0.4
            ],
            [
              15,
              0.75
            ],
            [
              20,
              2
            ]
          ]
        },
        "line-dasharray": [
          2,
          2
        ]
      }
    },
    {
      "id": "ferry",
      "type": "line",
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "in",
          "class",
          "ferry"
        ]
      ],
      "layout": {
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "rgba(108, 159, 182, 1)",
        "line-width": 1.1,
        "line-dasharray": [
          2,
          2
        ]
      }
    },
    {
      "id": "aeroway-taxiway-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "aeroway",
      "minzoom": 12,
      "filter": [
        "all",
        [
          "in",
          "class",
          "taxiway"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "rgba(153, 153, 153, 1)",
        "line-width": {
          "base": 1.5,
          "stops": [
            [
              11,
              2
            ],
            [
              17,
              12
            ]
          ]
        },
        "line-opacity": 1
      }
    },
    {
      "id": "aeroway-runway-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "aeroway",
      "minzoom": 12,
      "filter": [
        "all",
        [
          "in",
          "class",
          "runway"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "rgba(153, 153, 153, 1)",
        "line-width": {
          "base": 1.5,
          "stops": [
            [
              11,
              5
            ],
            [
              17,
              55
            ]
          ]
        },
        "line-opacity": 1
      }
    },
    {
      "id": "aeroway-taxiway",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "aeroway",
      "minzoom": 4,
      "filter": [
        "all",
        [
          "in",
          "class",
          "taxiway"
        ],
        [
          "==",
          "$type",
          "LineString"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "rgba(255, 255, 255, 1)",
        "line-width": {
          "base": 1.5,
          "stops": [
            [
              11,
              1
            ],
            [
              17,
              10
            ]
          ]
        },
        "line-opacity": {
          "base": 1,
          "stops": [
            [
              11,
              0
            ],
            [
              12,
              1
            ]
          ]
        }
      }
    },
    {
      "id": "aeroway-runway",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "aeroway",
      "minzoom": 4,
      "filter": [
        "all",
        [
          "in",
          "class",
          "runway"
        ],
        [
          "==",
          "$type",
          "LineString"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "rgba(255, 255, 255, 1)",
        "line-width": {
          "base": 1.5,
          "stops": [
            [
              11,
              4
            ],
            [
              17,
              50
            ]
          ]
        },
        "line-opacity": {
          "base": 1,
          "stops": [
            [
              11,
              0
            ],
            [
              12,
              1
            ]
          ]
        }
      }
    },
    {
      "id": "highway-motorway-link-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 12,
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "==",
          "class",
          "motorway_link"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": 1,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12,
              1
            ],
            [
              13,
              3
            ],
            [
              14,
              4
            ],
            [
              20,
              15
            ]
          ]
        }
      }
    },
    {
      "id": "highway-link-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 13,
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "in",
          "class",
          "primary_link",
          "secondary_link",
          "tertiary_link",
          "trunk_link"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": 1,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12,
              1
            ],
            [
              13,
              3
            ],
            [
              14,
              4
            ],
            [
              20,
              15
            ]
          ]
        }
      }
    },
    {
      "id": "highway-minor-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "!=",
            "brunnel",
            "tunnel"
          ],
          [
            "in",
            "class",
            "minor",
            "service",
            "track"
          ]
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#cfcdca",
        "line-opacity": {
          "stops": [
            [
              12,
              0
            ],
            [
              12.5,
              0
            ]
          ]
        },
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12,
              0.5
            ],
            [
              13,
              1
            ],
            [
              14,
              4
            ],
            [
              20,
              15
            ]
          ]
        }
      }
    },
    {
      "id": "highway-secondary-tertiary-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": 0.5,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              8,
              1.5
            ],
            [
              20,
              17
            ]
          ]
        }
      }
    },
    {
      "id": "highway-primary-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 5,
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "in",
          "class",
          "primary"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": {
          "stops": [
            [
              7,
              0
            ],
            [
              8,
              0.6
            ]
          ]
        },
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              7,
              0
            ],
            [
              8,
              0.6
            ],
            [
              9,
              1.5
            ],
            [
              20,
              22
            ]
          ]
        }
      }
    },
    {
      "id": "highway-trunk-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 5,
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "in",
          "class",
          "trunk"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": {
          "stops": [
            [
              5,
              0
            ],
            [
              6,
              0.5
            ]
          ]
        },
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              5,
              0
            ],
            [
              6,
              0.6
            ],
            [
              7,
              1.5
            ],
            [
              20,
              22
            ]
          ]
        }
      }
    },
    {
      "id": "highway-motorway-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 4,
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "==",
          "class",
          "motorway"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              4,
              0
            ],
            [
              5,
              0.4
            ],
            [
              6,
              0.6
            ],
            [
              7,
              1.5
            ],
            [
              20,
              22
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              4,
              0
            ],
            [
              5,
              0.5
            ]
          ]
        }
      }
    },
    {
      "id": "highway-path",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "!in",
            "brunnel",
            "bridge",
            "tunnel"
          ],
          [
            "==",
            "class",
            "path"
          ]
        ]
      ],
      "paint": {
        "line-color": "#cba",
        "line-dasharray": [
          1.5,
          0.75
        ],
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              15,
              1.2
            ],
            [
              20,
              4
            ]
          ]
        }
      }
    },
    {
      "id": "highway-motorway-link",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 12,
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "==",
          "class",
          "motorway_link"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fc8",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12.5,
              0
            ],
            [
              13,
              1.5
            ],
            [
              14,
              2.5
            ],
            [
              20,
              11.5
            ]
          ]
        }
      }
    },
    {
      "id": "highway-link",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 13,
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "in",
          "class",
          "primary_link",
          "secondary_link",
          "tertiary_link",
          "trunk_link"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#fea",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12.5,
              0
            ],
            [
              13,
              1.5
            ],
            [
              14,
              2.5
            ],
            [
              20,
              11.5
            ]
          ]
        }
      }
    },
    {
      "id": "highway-minor",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "!=",
            "brunnel",
            "tunnel"
          ],
          [
            "in",
            "class",
            "minor",
            "service",
            "track"
          ]
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fff",
        "line-opacity": 0.5,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              13.5,
              0
            ],
            [
              14,
              2.5
            ],
            [
              20,
              11.5
            ]
          ]
        }
      }
    },
    {
      "id": "highway-secondary-tertiary",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "!in",
          "brunnel",
          "bridge",
          "tunnel"
        ],
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#fea",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              8,
              0.5
            ],
            [
              20,
              13
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "highway-primary",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "!in",
            "brunnel",
            "bridge",
            "tunnel"
          ],
          [
            "in",
            "class",
            "primary"
          ]
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#fea",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              8.5,
              0
            ],
            [
              9,
              0.5
            ],
            [
              20,
              18
            ]
          ]
        },
        "line-opacity": 0
      }
    },
    {
      "id": "highway-trunk",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "!in",
            "brunnel",
            "bridge",
            "tunnel"
          ],
          [
            "in",
            "class",
            "trunk"
          ]
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#fea",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              7,
              0.5
            ],
            [
              20,
              18
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "highway-motorway",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 5,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "!in",
            "brunnel",
            "bridge",
            "tunnel"
          ],
          [
            "==",
            "class",
            "motorway"
          ]
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-color": "#fc8",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              7,
              0.5
            ],
            [
              20,
              18
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "railway-transit",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "==",
            "class",
            "transit"
          ],
          [
            "!in",
            "brunnel",
            "tunnel"
          ]
        ]
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "line-color": "hsla(0, 0%, 73%, 0.77)",
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14,
              0.4
            ],
            [
              20,
              1
            ]
          ]
        }
      }
    },
    {
      "id": "railway-transit-hatching",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "==",
            "class",
            "transit"
          ],
          [
            "!in",
            "brunnel",
            "tunnel"
          ]
        ]
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "line-color": "hsla(0, 0%, 73%, 0.68)",
        "line-dasharray": [
          0.2,
          8
        ],
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14.5,
              0
            ],
            [
              15,
              2
            ],
            [
              20,
              6
            ]
          ]
        }
      }
    },
    {
      "id": "railway-service",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "==",
            "class",
            "rail"
          ],
          [
            "has",
            "service"
          ]
        ]
      ],
      "paint": {
        "line-color": "hsla(0, 0%, 73%, 0.77)",
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14,
              0.4
            ],
            [
              20,
              1
            ]
          ]
        }
      }
    },
    {
      "id": "railway-service-hatching",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "==",
            "class",
            "rail"
          ],
          [
            "has",
            "service"
          ]
        ]
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "line-color": "hsla(0, 0%, 73%, 0.68)",
        "line-dasharray": [
          0.2,
          8
        ],
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14.5,
              0
            ],
            [
              15,
              2
            ],
            [
              20,
              6
            ]
          ]
        }
      }
    },
    {
      "id": "railway",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "!has",
            "service"
          ],
          [
            "!in",
            "brunnel",
            "bridge",
            "tunnel"
          ],
          [
            "==",
            "class",
            "rail"
          ]
        ]
      ],
      "paint": {
        "line-color": "#bbb",
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14,
              0.4
            ],
            [
              15,
              0.75
            ],
            [
              20,
              2
            ]
          ]
        }
      }
    },
    {
      "id": "railway-hatching",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849345966.4436"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "!has",
            "service"
          ],
          [
            "!in",
            "brunnel",
            "bridge",
            "tunnel"
          ],
          [
            "==",
            "class",
            "rail"
          ]
        ]
      ],
      "paint": {
        "line-color": "#bbb",
        "line-dasharray": [
          0.2,
          8
        ],
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14.5,
              0
            ],
            [
              15,
              3
            ],
            [
              20,
              8
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-motorway-link-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "==",
          "class",
          "motorway_link"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": 1,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12,
              1
            ],
            [
              13,
              3
            ],
            [
              14,
              4
            ],
            [
              20,
              15
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-link-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "in",
          "class",
          "primary_link",
          "secondary_link",
          "tertiary_link",
          "trunk_link"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": 1,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12,
              1
            ],
            [
              13,
              3
            ],
            [
              14,
              4
            ],
            [
              20,
              15
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-secondary-tertiary-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-opacity": 1,
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              8,
              1.5
            ],
            [
              20,
              28
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-trunk-primary-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "in",
          "class",
          "primary",
          "trunk"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "hsl(28, 76%, 67%)",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              5,
              0.4
            ],
            [
              6,
              0.6
            ],
            [
              7,
              1.5
            ],
            [
              20,
              26
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-motorway-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "==",
          "class",
          "motorway"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#e9ac77",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              5,
              0.4
            ],
            [
              6,
              0.6
            ],
            [
              7,
              1.5
            ],
            [
              20,
              22
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "bridge-path-casing",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "==",
            "brunnel",
            "bridge"
          ],
          [
            "==",
            "class",
            "path"
          ]
        ]
      ],
      "paint": {
        "line-color": "#f8f4f0",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              15,
              1.2
            ],
            [
              20,
              18
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-path",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "all",
          [
            "==",
            "brunnel",
            "bridge"
          ],
          [
            "==",
            "class",
            "path"
          ]
        ]
      ],
      "paint": {
        "line-color": "#cba",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              15,
              1.2
            ],
            [
              20,
              4
            ]
          ]
        },
        "line-dasharray": [
          1.5,
          0.75
        ]
      }
    },
    {
      "id": "bridge-motorway-link",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "==",
          "class",
          "motorway_link"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fc8",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12.5,
              0
            ],
            [
              13,
              1.5
            ],
            [
              14,
              2.5
            ],
            [
              20,
              11.5
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-link",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "in",
          "class",
          "primary_link",
          "secondary_link",
          "tertiary_link",
          "trunk_link"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fea",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              12.5,
              0
            ],
            [
              13,
              1.5
            ],
            [
              14,
              2.5
            ],
            [
              20,
              11.5
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-secondary-tertiary",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fea",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              7,
              0.5
            ],
            [
              20,
              20
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-trunk-primary",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "in",
          "class",
          "primary",
          "trunk"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fea",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              7,
              0.5
            ],
            [
              20,
              18
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-motorway",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "==",
          "class",
          "motorway"
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#fc8",
        "line-width": {
          "base": 1.2,
          "stops": [
            [
              6.5,
              0
            ],
            [
              7,
              0.5
            ],
            [
              20,
              18
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "bridge-railway",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "==",
          "class",
          "rail"
        ]
      ],
      "paint": {
        "line-color": "#bbb",
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14,
              0.4
            ],
            [
              15,
              0.75
            ],
            [
              20,
              2
            ]
          ]
        }
      }
    },
    {
      "id": "bridge-railway-hatching",
      "type": "line",
      "metadata": {
        "mapbox:group": "1444849334699.1902"
      },
      "source": "openmaptiles",
      "source-layer": "transportation",
      "filter": [
        "all",
        [
          "==",
          "brunnel",
          "bridge"
        ],
        [
          "==",
          "class",
          "rail"
        ]
      ],
      "paint": {
        "line-color": "#bbb",
        "line-dasharray": [
          0.2,
          8
        ],
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              14.5,
              0
            ],
            [
              15,
              3
            ],
            [
              20,
              8
            ]
          ]
        }
      }
    },
    {
      "id": "cablecar",
      "type": "line",
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 13,
      "filter": [
        "==",
        "class",
        "cable_car"
      ],
      "layout": {
        "visibility": "visible",
        "line-cap": "round"
      },
      "paint": {
        "line-color": "hsl(0, 0%, 70%)",
        "line-width": {
          "base": 1,
          "stops": [
            [
              11,
              1
            ],
            [
              19,
              2.5
            ]
          ]
        }
      }
    },
    {
      "id": "cablecar-dash",
      "type": "line",
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 13,
      "filter": [
        "==",
        "class",
        "cable_car"
      ],
      "layout": {
        "visibility": "visible",
        "line-cap": "round"
      },
      "paint": {
        "line-color": "hsl(0, 0%, 70%)",
        "line-width": {
          "base": 1,
          "stops": [
            [
              11,
              3
            ],
            [
              19,
              5.5
            ]
          ]
        },
        "line-dasharray": [
          2,
          3
        ]
      }
    },
    {
      "id": "boundary-land-level-4",
      "type": "line",
      "source": "openmaptiles",
      "source-layer": "boundary",
      "filter": [
        "all",
        [
          ">=",
          "admin_level",
          4
        ],
        [
          "<=",
          "admin_level",
          8
        ],
        [
          "!=",
          "maritime",
          1
        ]
      ],
      "layout": {
        "line-join": "round"
      },
      "paint": {
        "line-color": "#9e9cab",
        "line-dasharray": [
          3,
          1,
          1,
          1
        ],
        "line-width": {
          "base": 1.4,
          "stops": [
            [
              4,
              0.4
            ],
            [
              5,
              1
            ],
            [
              12,
              3
            ]
          ]
        },
        "line-opacity": 0.6
      }
    },
    {
      "id": "boundary-land-level-2",
      "type": "line",
      "source": "openmaptiles",
      "source-layer": "boundary",
      "filter": [
        "all",
        [
          "==",
          "admin_level",
          2
        ],
        [
          "!=",
          "maritime",
          1
        ],
        [
          "!=",
          "disputed",
          1
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": "hsl(248, 7%, 66%)",
        "line-width": {
          "base": 1,
          "stops": [
            [
              0,
              0.6
            ],
            [
              4,
              1.4
            ],
            [
              5,
              2
            ],
            [
              12,
              2
            ]
          ]
        }
      }
    },
    {
      "id": "boundary-land-disputed",
      "type": "line",
      "source": "openmaptiles",
      "source-layer": "boundary",
      "filter": [
        "all",
        [
          "!=",
          "maritime",
          1
        ],
        [
          "==",
          "disputed",
          1
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": "hsl(248, 7%, 70%)",
        "line-dasharray": [
          1,
          3
        ],
        "line-width": {
          "base": 1,
          "stops": [
            [
              0,
              0.6
            ],
            [
              4,
              1.4
            ],
            [
              5,
              2
            ],
            [
              12,
              8
            ]
          ]
        }
      }
    },
    {
      "id": "boundary-water",
      "type": "line",
      "source": "openmaptiles",
      "source-layer": "boundary",
      "filter": [
        "all",
        [
          "in",
          "admin_level",
          2,
          4
        ],
        [
          "==",
          "maritime",
          1
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": "rgba(154, 189, 214, 1)",
        "line-width": {
          "base": 1,
          "stops": [
            [
              0,
              0.6
            ],
            [
              4,
              1
            ],
            [
              5,
              1
            ],
            [
              12,
              1
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              6,
              0
            ],
            [
              10,
              0
            ]
          ]
        }
      }
    },
    {
      "id": "waterway-name",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "waterway",
      "minzoom": 13,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "has",
          "name"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Italic"
        ],
        "text-size": 14,
        "text-field": "{name:latin} {name:nonlatin}",
        "text-max-width": 5,
        "text-rotation-alignment": "map",
        "symbol-placement": "line",
        "text-letter-spacing": 0.2,
        "symbol-spacing": 350
      },
      "paint": {
        "text-color": "#74aee9",
        "text-halo-width": 1.5,
        "text-halo-color": "rgba(255,255,255,0.7)"
      }
    },
    {
      "id": "water-name-lakeline",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "water_name",
      "filter": [
        "==",
        "$type",
        "LineString"
      ],
      "layout": {
        "text-font": [
          "Noto Sans Italic"
        ],
        "text-size": 14,
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-max-width": 5,
        "text-rotation-alignment": "map",
        "symbol-placement": "line",
        "symbol-spacing": 350,
        "text-letter-spacing": 0.2
      },
      "paint": {
        "text-color": "#74aee9",
        "text-halo-width": 1.5,
        "text-halo-color": "rgba(255,255,255,0.7)"
      }
    },
    {
      "id": "water-name-ocean",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "water_name",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "Point"
        ],
        [
          "==",
          "class",
          "ocean"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Italic"
        ],
        "text-size": 14,
        "text-field": "{name:latin}",
        "text-max-width": 5,
        "text-rotation-alignment": "map",
        "symbol-placement": "point",
        "symbol-spacing": 350,
        "text-letter-spacing": 0.2
      },
      "paint": {
        "text-color": "#74aee9",
        "text-halo-width": 1.5,
        "text-halo-color": "rgba(255,255,255,0.7)"
      }
    },
    {
      "id": "water-name-other",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "water_name",
      "filter": [
        "all",
        [
          "==",
          "$type",
          "Point"
        ],
        [
          "!in",
          "class",
          "ocean"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Italic"
        ],
        "text-size": {
          "stops": [
            [
              0,
              10
            ],
            [
              6,
              14
            ]
          ]
        },
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-max-width": 5,
        "text-rotation-alignment": "map",
        "symbol-placement": "point",
        "symbol-spacing": 350,
        "text-letter-spacing": 0.2,
        "visibility": "visible"
      },
      "paint": {
        "text-color": "#74aee9",
        "text-halo-width": 1.5,
        "text-halo-color": "rgba(255,255,255,0.7)"
      }
    },
    {
      "id": "poi-level-3",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "poi",
      "minzoom": 16,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "Point"
        ],
        [
          ">=",
          "rank",
          25
        ]
      ],
      "layout": {
        "text-padding": 2,
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-anchor": "top",
        "icon-image": "{class}_11",
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-offset": [
          0,
          0.6
        ],
        "text-size": 12,
        "text-max-width": 9
      },
      "paint": {
        "text-halo-blur": 0.5,
        "text-color": "#666",
        "text-halo-width": 1,
        "text-halo-color": "#ffffff"
      }
    },
    {
      "id": "poi-level-2",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "poi",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "Point"
        ],
        [
          "<=",
          "rank",
          24
        ],
        [
          ">=",
          "rank",
          15
        ]
      ],
      "layout": {
        "text-padding": 2,
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-anchor": "top",
        "icon-image": "{class}_11",
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-offset": [
          0,
          0.6
        ],
        "text-size": 12,
        "text-max-width": 9
      },
      "paint": {
        "text-halo-blur": 0.5,
        "text-color": "#666",
        "text-halo-width": 1,
        "text-halo-color": "#ffffff"
      }
    },
    {
      "id": "poi-level-1",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "poi",
      "minzoom": 14,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "Point"
        ],
        [
          "<=",
          "rank",
          14
        ],
        [
          "has",
          "name"
        ]
      ],
      "layout": {
        "text-padding": 2,
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-anchor": "top",
        "icon-image": "{class}_11",
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-offset": [
          0,
          0.6
        ],
        "text-size": 11,
        "text-max-width": 9
      },
      "paint": {
        "text-halo-blur": 0.5,
        "text-color": "rgba(191, 228, 172, 1)",
        "text-halo-width": 1,
        "text-halo-color": "rgba(30, 29, 29, 1)"
      }
    },
    {
      "id": "poi-railway",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "poi",
      "minzoom": 13,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "Point"
        ],
        [
          "has",
          "name"
        ],
        [
          "==",
          "class",
          "railway"
        ],
        [
          "==",
          "subclass",
          "station"
        ]
      ],
      "layout": {
        "text-padding": 2,
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-anchor": "top",
        "icon-image": "{class}_11",
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-offset": [
          0,
          0.6
        ],
        "text-size": 12,
        "text-max-width": 9,
        "icon-optional": false,
        "icon-ignore-placement": false,
        "icon-allow-overlap": false,
        "text-ignore-placement": false,
        "text-allow-overlap": false,
        "text-optional": true
      },
      "paint": {
        "text-halo-blur": 0.5,
        "text-color": "#666",
        "text-halo-width": 1,
        "text-halo-color": "#ffffff"
      }
    },
    {
      "id": "road_oneway",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "oneway",
          1
        ],
        [
          "in",
          "class",
          "motorway",
          "trunk",
          "primary",
          "secondary",
          "tertiary",
          "minor",
          "service"
        ]
      ],
      "layout": {
        "symbol-placement": "line",
        "icon-image": "oneway",
        "symbol-spacing": 75,
        "icon-padding": 2,
        "icon-rotation-alignment": "map",
        "icon-rotate": 90,
        "icon-size": {
          "stops": [
            [
              15,
              0.5
            ],
            [
              19,
              1
            ]
          ]
        }
      },
      "paint": {
        "icon-opacity": 0.5
      }
    },
    {
      "id": "road_oneway_opposite",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "transportation",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "oneway",
          -1
        ],
        [
          "in",
          "class",
          "motorway",
          "trunk",
          "primary",
          "secondary",
          "tertiary",
          "minor",
          "service"
        ]
      ],
      "layout": {
        "symbol-placement": "line",
        "icon-image": "oneway",
        "symbol-spacing": 75,
        "icon-padding": 2,
        "icon-rotation-alignment": "map",
        "icon-rotate": -90,
        "icon-size": {
          "stops": [
            [
              15,
              0.5
            ],
            [
              19,
              1
            ]
          ]
        }
      },
      "paint": {
        "icon-opacity": 0.5
      }
    },
    {
      "id": "highway-name-path",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "transportation_name",
      "minzoom": 15.5,
      "filter": [
        "==",
        "class",
        "path"
      ],
      "layout": {
        "text-size": {
          "base": 1,
          "stops": [
            [
              13,
              12
            ],
            [
              14,
              13
            ]
          ]
        },
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-field": "{name:latin} {name:nonlatin}",
        "symbol-placement": "line",
        "text-rotation-alignment": "map"
      },
      "paint": {
        "text-halo-color": "#f8f4f0",
        "text-color": "hsl(30, 23%, 62%)",
        "text-halo-width": 0.5
      }
    },
    {
      "id": "highway-name-minor",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "transportation_name",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "in",
          "class",
          "minor",
          "service",
          "track"
        ]
      ],
      "layout": {
        "text-size": {
          "base": 1,
          "stops": [
            [
              13,
              12
            ],
            [
              14,
              13
            ]
          ]
        },
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-field": "{name:latin} {name:nonlatin}",
        "symbol-placement": "line",
        "text-rotation-alignment": "map"
      },
      "paint": {
        "text-halo-blur": 0.5,
        "text-color": "#765",
        "text-halo-width": 1
      }
    },
    {
      "id": "highway-name-major",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "transportation_name",
      "minzoom": 12.2,
      "filter": [
        "in",
        "class",
        "primary",
        "secondary",
        "tertiary",
        "trunk"
      ],
      "layout": {
        "text-size": {
          "base": 1,
          "stops": [
            [
              13,
              12
            ],
            [
              14,
              13
            ]
          ]
        },
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-field": "{name:latin} {name:nonlatin}",
        "symbol-placement": "line",
        "text-rotation-alignment": "map"
      },
      "paint": {
        "text-halo-blur": 0.5,
        "text-color": "#765",
        "text-halo-width": 1
      }
    },
    {
      "id": "highway-shield",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "transportation_name",
      "minzoom": 8,
      "filter": [
        "all",
        [
          "<=",
          "ref_length",
          6
        ],
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "!in",
          "network",
          "us-interstate",
          "us-highway",
          "us-state"
        ]
      ],
      "layout": {
        "text-size": 10,
        "icon-image": "road_{ref_length}",
        "icon-rotation-alignment": "viewport",
        "symbol-spacing": 200,
        "text-font": [
          "Noto Sans Regular"
        ],
        "symbol-placement": {
          "base": 1,
          "stops": [
            [
              10,
              "point"
            ],
            [
              11,
              "line"
            ]
          ]
        },
        "text-rotation-alignment": "viewport",
        "icon-size": 1,
        "text-field": "{ref}"
      },
      "paint": {
        "text-opacity": 1,
        "text-color": "rgba(20, 19, 19, 1)",
        "text-halo-color": "rgba(230, 221, 221, 0)",
        "text-halo-width": 2,
        "icon-color": "rgba(183, 18, 18, 1)",
        "icon-opacity": 0.3,
        "icon-halo-color": "rgba(183, 55, 55, 0)"
      }
    },
    {
      "id": "highway-shield-us-interstate",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "transportation_name",
      "minzoom": 7,
      "filter": [
        "all",
        [
          "<=",
          "ref_length",
          6
        ],
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "in",
          "network",
          "us-interstate"
        ]
      ],
      "layout": {
        "text-size": 10,
        "icon-image": "{network}_{ref_length}",
        "icon-rotation-alignment": "viewport",
        "symbol-spacing": 200,
        "text-font": [
          "Noto Sans Regular"
        ],
        "symbol-placement": {
          "base": 1,
          "stops": [
            [
              7,
              "point"
            ],
            [
              7,
              "line"
            ],
            [
              8,
              "line"
            ]
          ]
        },
        "text-rotation-alignment": "viewport",
        "icon-size": 1,
        "text-field": "{ref}"
      },
      "paint": {
        "text-color": "rgba(0, 0, 0, 1)"
      }
    },
    {
      "id": "highway-shield-us-other",
      "type": "symbol",
      "source": "openmaptiles",
      "source-layer": "transportation_name",
      "minzoom": 9,
      "filter": [
        "all",
        [
          "<=",
          "ref_length",
          6
        ],
        [
          "==",
          "$type",
          "LineString"
        ],
        [
          "in",
          "network",
          "us-highway",
          "us-state"
        ]
      ],
      "layout": {
        "text-size": 10,
        "icon-image": "{network}_{ref_length}",
        "icon-rotation-alignment": "viewport",
        "symbol-spacing": 200,
        "text-font": [
          "Noto Sans Regular"
        ],
        "symbol-placement": {
          "base": 1,
          "stops": [
            [
              10,
              "point"
            ],
            [
              11,
              "line"
            ]
          ]
        },
        "text-rotation-alignment": "viewport",
        "icon-size": 1,
        "text-field": "{ref}"
      },
      "paint": {
        "text-color": "rgba(0, 0, 0, 1)"
      }
    },
    {
      "id": "place-other",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "minzoom": 12,
      "filter": [
        "!in",
        "class",
        "city",
        "town",
        "village",
        "country",
        "continent"
      ],
      "layout": {
        "text-letter-spacing": 0.1,
        "text-size": {
          "base": 1.2,
          "stops": [
            [
              12,
              10
            ],
            [
              15,
              14
            ]
          ]
        },
        "text-font": [
          "Noto Sans Bold"
        ],
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-transform": "uppercase",
        "text-max-width": 9,
        "visibility": "visible"
      },
      "paint": {
        "text-color": "rgba(255,255,255,1)",
        "text-halo-width": 1.2,
        "text-halo-color": "rgba(57, 28, 28, 1)"
      }
    },
    {
      "id": "place-village",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "minzoom": 10,
      "filter": [
        "==",
        "class",
        "village"
      ],
      "layout": {
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-size": {
          "base": 1.2,
          "stops": [
            [
              10,
              12
            ],
            [
              15,
              16
            ]
          ]
        },
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-max-width": 8,
        "visibility": "visible"
      },
      "paint": {
        "text-color": "rgba(255, 255, 255, 1)",
        "text-halo-width": 1.2,
        "text-halo-color": "rgba(10, 9, 9, 0.8)"
      }
    },
    {
      "id": "place-town",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "filter": [
        "==",
        "class",
        "town"
      ],
      "layout": {
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-size": {
          "base": 1.2,
          "stops": [
            [
              10,
              14
            ],
            [
              15,
              24
            ]
          ]
        },
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-max-width": 8,
        "visibility": "visible"
      },
      "paint": {
        "text-color": "rgba(255, 255, 255, 1)",
        "text-halo-width": 1.2,
        "text-halo-color": "rgba(22, 22, 22, 0.8)"
      }
    },
    {
      "id": "place-city",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "filter": [
        "all",
        [
          "!=",
          "capital",
          2
        ],
        [
          "==",
          "class",
          "city"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-size": {
          "base": 1.2,
          "stops": [
            [
              7,
              14
            ],
            [
              11,
              24
            ]
          ]
        },
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-max-width": 8,
        "visibility": "visible"
      },
      "paint": {
        "text-color": "rgba(0, 0, 0, 1)",
        "text-halo-width": 1.2,
        "text-halo-color": "rgba(255,255,255,0.8)"
      }
    },
    {
      "id": "place-city-capital",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "filter": [
        "all",
        [
          "==",
          "capital",
          2
        ],
        [
          "==",
          "class",
          "city"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Regular"
        ],
        "text-size": {
          "base": 1.2,
          "stops": [
            [
              7,
              14
            ],
            [
              11,
              24
            ]
          ]
        },
        "text-field": "{name:latin}\n{name:nonlatin}",
        "text-max-width": 8,
        "icon-image": "star_11",
        "text-offset": [
          0.4,
          0
        ],
        "icon-size": 0.8,
        "text-anchor": "left",
        "visibility": "visible"
      },
      "paint": {
        "text-color": "#333",
        "text-halo-width": 1.2,
        "text-halo-color": "rgba(255,255,255,0.8)"
      }
    },
    {
      "id": "place-country-other",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "filter": [
        "all",
        [
          "==",
          "class",
          "country"
        ],
        [
          ">=",
          "rank",
          3
        ],
        [
          "!has",
          "iso_a2"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Italic"
        ],
        "text-field": "{name:latin}",
        "text-size": {
          "stops": [
            [
              3,
              11
            ],
            [
              7,
              17
            ]
          ]
        },
        "text-transform": "uppercase",
        "text-max-width": 6.25,
        "visibility": "visible"
      },
      "paint": {
        "text-halo-blur": 1,
        "text-color": "#334",
        "text-halo-width": 2,
        "text-halo-color": "rgba(255,255,255,0.8)"
      }
    },
    {
      "id": "place-country-3",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "filter": [
        "all",
        [
          "==",
          "class",
          "country"
        ],
        [
          ">=",
          "rank",
          3
        ],
        [
          "has",
          "iso_a2"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Bold"
        ],
        "text-field": "{name:latin}",
        "text-size": {
          "stops": [
            [
              3,
              11
            ],
            [
              7,
              17
            ]
          ]
        },
        "text-transform": "uppercase",
        "text-max-width": 6.25,
        "visibility": "visible"
      },
      "paint": {
        "text-halo-blur": 1,
        "text-color": "#334",
        "text-halo-width": 2,
        "text-halo-color": "rgba(255,255,255,0.8)"
      }
    },
    {
      "id": "place-country-2",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "filter": [
        "all",
        [
          "==",
          "class",
          "country"
        ],
        [
          "==",
          "rank",
          2
        ],
        [
          "has",
          "iso_a2"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Bold"
        ],
        "text-field": "{name:latin}",
        "text-size": {
          "stops": [
            [
              2,
              11
            ],
            [
              5,
              17
            ]
          ]
        },
        "text-transform": "uppercase",
        "text-max-width": 6.25,
        "visibility": "visible"
      },
      "paint": {
        "text-halo-blur": 1,
        "text-color": "#334",
        "text-halo-width": 2,
        "text-halo-color": "rgba(255,255,255,0.8)"
      }
    },
    {
      "id": "place-country-1",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "filter": [
        "all",
        [
          "==",
          "class",
          "country"
        ],
        [
          "==",
          "rank",
          1
        ],
        [
          "has",
          "iso_a2"
        ]
      ],
      "layout": {
        "text-font": [
          "Noto Sans Bold"
        ],
        "text-field": "{name:latin}",
        "text-size": {
          "stops": [
            [
              1,
              11
            ],
            [
              4,
              17
            ]
          ]
        },
        "text-transform": "uppercase",
        "text-max-width": 6.25,
        "visibility": "visible"
      },
      "paint": {
        "text-halo-blur": 1,
        "text-color": "#334",
        "text-halo-width": 2,
        "text-halo-color": "rgba(255,255,255,0.8)"
      }
    },
    {
      "id": "place-continent",
      "type": "symbol",
      "metadata": {
        "mapbox:group": "1444849242106.713"
      },
      "source": "openmaptiles",
      "source-layer": "place",
      "maxzoom": 1,
      "filter": [
        "==",
        "class",
        "continent"
      ],
      "layout": {
        "text-font": [
          "Noto Sans Bold"
        ],
        "text-field": "{name:latin}",
        "text-size": 14,
        "text-max-width": 6.25,
        "text-transform": "uppercase",
        "visibility": "visible"
      },
      "paint": {
        "text-halo-blur": 1,
        "text-color": "#334",
        "text-halo-width": 2,
        "text-halo-color": "rgba(255,255,255,0.8)"
      }
    }
  ],
  "id": "qebnlkra6"
}

window.mapStyles["arcgissatellite"] = {
  "version": 8,
  "name": "ArcGIS Satellite",
  "metadata": {},
  "center": [
    1.537786,
    41.837539
  ],
  "zoom": 12,
  "bearing": 0,
  "pitch": 0,
  "light": {
    "anchor": "viewport",
    "color": "white",
    "intensity": 0.4,
    "position": [
      1.15,
      45,
      30
    ]
  },
  "sources": {
    "ortoEsri": {
      "type": "raster",
      "tiles": [
        "https://server.arcgisonline.com/ArcGIS/rest/services/World_Imagery/MapServer/tile/{z}/{y}/{x}"
      ],
      "tileSize": 256,
      "maxzoom": 18,
      "attribution": "ESRI &copy; <a href='http://www.esri.com'>ESRI</a>"
    },
    "ortoInstaMaps": {
      "type": "raster",
      "tiles": [
        "https://tilemaps.icgc.cat/mapfactory/wmts/orto_8_12/CAT3857/{z}/{x}/{y}.png"
      ],
      "tileSize": 256,
      "maxzoom": 13
    },
    "ortoICGC": {
      "type": "raster",
      "tiles": [
        "https://geoserveis.icgc.cat/icc_mapesmultibase/noutm/wmts/orto/GRID3857/{z}/{x}/{y}.jpeg"
      ],
      "tileSize": 256,
      "minzoom": 13.1,
      "maxzoom": 20
    },
    "openmaptiles": {
      "type": "vector",
      "url": "https://geoserveis.icgc.cat/contextmaps/basemap.json"
    }
  },
  "sprite": "https://geoserveis.icgc.cat/contextmaps/sprites/sprite@1",
  "glyphs": "https://geoserveis.icgc.cat/contextmaps/glyphs/{fontstack}/{range}.pbf",
  "layers": [
    {
      "id": "background",
      "type": "background",
      "paint": {
        "background-color": "#F4F9F4"
      }
    },
    {
      "id": "ortoEsri",
      "type": "raster",
      "source": "ortoEsri",
      "maxzoom": 16,
      "layout": {
        "visibility": "visible"
      }
    },
    {
      "id": "ortoICGC",
      "type": "raster",
      "source": "ortoICGC",
      "minzoom": 13.1,
      "maxzoom": 19,
      "layout": {
        "visibility": "visible"
      }
    },
    {
      "id": "ortoInstaMaps",
      "type": "raster",
      "source": "ortoInstaMaps",
      "maxzoom": 13,
      "layout": {
        "visibility": "visible"
      }
    }
  ],
  "id": "qebnlkra6"
}


window.mapStyles["positron"] = {

  "version": 8,
  "name": "Positron",
  "metadata": {},
  "sources": {
    "carto": {
      "type": "vector",
      "url": "https://tiles.basemaps.cartocdn.com/vector/carto.streets/v1/tiles.json"
    }
  },
  "sprite": "https://tiles.basemaps.cartocdn.com/gl/positron-gl-style/sprite",
  "glyphs": "https://tiles.basemaps.cartocdn.com/fonts/{fontstack}/{range}.pbf",
  "layers": [
    {
      "id": "background",
      "type": "background",
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "background-color": "#fafaf8",
        "background-opacity": 1
      }
    },
    {
      "id": "landcover",
      "type": "fill",
      "source": "carto",
      "source-layer": "landcover",
      "filter": [
        "any",
        [
          "==",
          "class",
          "wood"
        ],
        [
          "==",
          "class",
          "grass"
        ],
        [
          "==",
          "subclass",
          "recreation_ground"
        ]
      ],
      "paint": {
        "fill-color": {
          "stops": [
            [
              8,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              9,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              11,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              13,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              15,
              "rgba(234, 241, 233, 0.5)"
            ]
          ]
        },
        "fill-opacity": 1
      }
    },
    {
      "id": "park_national_park",
      "type": "fill",
      "source": "carto",
      "source-layer": "park",
      "minzoom": 9,
      "filter": [
        "all",
        [
          "==",
          "class",
          "national_park"
        ]
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-color": {
          "stops": [
            [
              8,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              9,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              11,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              13,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              15,
              "rgba(234, 241, 233, 0.5)"
            ]
          ]
        },
        "fill-opacity": 1,
        "fill-translate-anchor": "map"
      }
    },
    {
      "id": "park_nature_reserve",
      "type": "fill",
      "source": "carto",
      "source-layer": "park",
      "minzoom": 0,
      "filter": [
        "all",
        [
          "==",
          "class",
          "nature_reserve"
        ]
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-color": {
          "stops": [
            [
              8,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              9,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              11,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              13,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              15,
              "rgba(234, 241, 233, 0.5)"
            ]
          ]
        },
        "fill-antialias": true,
        "fill-opacity": {
          "stops": [
            [
              6,
              0.7
            ],
            [
              9,
              0.9
            ]
          ]
        }
      }
    },
    {
      "id": "landuse_residential",
      "type": "fill",
      "source": "carto",
      "source-layer": "landuse",
      "minzoom": 6,
      "filter": [
        "any",
        [
          "==",
          "class",
          "residential"
        ]
      ],
      "paint": {
        "fill-color": {
          "stops": [
            [
              5,
              "rgba(237, 237, 237, 0.5)"
            ],
            [
              8,
              "rgba(237, 237, 237, 0.45)"
            ],
            [
              9,
              "rgba(237, 237, 237, 0.4)"
            ],
            [
              11,
              "rgba(237, 237, 237, 0.35)"
            ],
            [
              13,
              "rgba(237, 237, 237, 0.3)"
            ],
            [
              15,
              "rgba(237, 237, 237, 0.25)"
            ],
            [
              16,
              "rgba(237, 237, 237, 0.25)"
            ]
          ]
        },
        "fill-opacity": {
          "stops": [
            [
              6,
              0.6
            ],
            [
              9,
              1
            ]
          ]
        }
      }
    },
    {
      "id": "landuse",
      "type": "fill",
      "source": "carto",
      "source-layer": "landuse",
      "filter": [
        "any",
        [
          "==",
          "class",
          "cemetery"
        ],
        [
          "==",
          "class",
          "stadium"
        ]
      ],
      "paint": {
        "fill-color": {
          "stops": [
            [
              8,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              9,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              11,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              13,
              "rgba(234, 241, 233, 0.5)"
            ],
            [
              15,
              "rgba(234, 241, 233, 0.5)"
            ]
          ]
        }
      }
    },
    {
      "id": "waterway",
      "type": "line",
      "source": "carto",
      "source-layer": "waterway",
      "paint": {
        "line-color": "#d1dbdf",
        "line-width": {
          "stops": [
            [
              8,
              0.5
            ],
            [
              9,
              1
            ],
            [
              15,
              2
            ],
            [
              16,
              3
            ]
          ]
        }
      }
    },
    {
      "id": "boundary_county",
      "type": "line",
      "source": "carto",
      "source-layer": "boundary",
      "minzoom": 9,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "admin_level",
          6
        ],
        [
          "==",
          "maritime",
          0
        ]
      ],
      "paint": {
        "line-color": {
          "stops": [
            [
              4,
              "#ead5d7"
            ],
            [
              5,
              "#ead5d7"
            ],
            [
              6,
              "#e1c5c7"
            ]
          ]
        },
        "line-width": {
          "stops": [
            [
              4,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-dasharray": {
          "stops": [
            [
              6,
              [
                1
              ]
            ],
            [
              7,
              [
                2,
                2
              ]
            ]
          ]
        }
      }
    },
    {
      "id": "boundary_state",
      "type": "line",
      "source": "carto",
      "source-layer": "boundary",
      "minzoom": 4,
      "filter": [
        "all",
        [
          "==",
          "admin_level",
          4
        ],
        [
          "==",
          "maritime",
          0
        ]
      ],
      "paint": {
        "line-color": {
          "stops": [
            [
              4,
              "#ead5d7"
            ],
            [
              5,
              "#ead5d7"
            ],
            [
              6,
              "#e1c5c7"
            ]
          ]
        },
        "line-width": {
          "stops": [
            [
              4,
              0.5
            ],
            [
              7,
              1
            ],
            [
              8,
              1
            ],
            [
              9,
              1.2
            ]
          ]
        },
        "line-dasharray": {
          "stops": [
            [
              6,
              [
                1
              ]
            ],
            [
              7,
              [
                2,
                2
              ]
            ]
          ]
        }
      }
    },
    {
      "id": "water",
      "type": "fill",
      "source": "carto",
      "source-layer": "water",
      "minzoom": 0,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "Polygon"
        ]
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-color": "#d4dadc",
        "fill-antialias": true,
        "fill-translate-anchor": "map",
        "fill-opacity": 1
      }
    },
    {
      "id": "water_shadow",
      "type": "fill",
      "source": "carto",
      "source-layer": "water",
      "minzoom": 0,
      "filter": [
        "all",
        [
          "==",
          "$type",
          "Polygon"
        ]
      ],
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-color": "transparent",
        "fill-antialias": true,
        "fill-translate-anchor": "map",
        "fill-opacity": 1,
        "fill-translate": {
          "stops": [
            [
              0,
              [
                0,
                2
              ]
            ],
            [
              6,
              [
                0,
                1
              ]
            ],
            [
              14,
              [
                0,
                1
              ]
            ],
            [
              17,
              [
                0,
                2
              ]
            ]
          ]
        }
      }
    },
    {
      "id": "aeroway-runway",
      "type": "line",
      "source": "carto",
      "source-layer": "aeroway",
      "minzoom": 12,
      "filter": [
        "all",
        [
          "==",
          "class",
          "runway"
        ]
      ],
      "layout": {
        "line-cap": "square"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              1
            ],
            [
              13,
              4
            ],
            [
              14,
              6
            ],
            [
              15,
              8
            ],
            [
              16,
              10
            ]
          ]
        },
        "line-color": "#e8e8e8"
      }
    },
    {
      "id": "aeroway-taxiway",
      "type": "line",
      "source": "carto",
      "source-layer": "aeroway",
      "minzoom": 13,
      "filter": [
        "all",
        [
          "==",
          "class",
          "taxiway"
        ]
      ],
      "paint": {
        "line-color": "#e8e8e8",
        "line-width": {
          "stops": [
            [
              13,
              0.5
            ],
            [
              14,
              1
            ],
            [
              15,
              2
            ],
            [
              16,
              4
            ]
          ]
        }
      }
    },
    {
      "id": "waterway_label",
      "type": "symbol",
      "source": "carto",
      "source-layer": "waterway",
      "filter": [
        "all",
        [
          "has",
          "name"
        ],
        [
          "==",
          "class",
          "river"
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Regular Italic",
          "Open Sans Italic",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "symbol-placement": "line",
        "symbol-spacing": 300,
        "symbol-avoid-edges": false,
        "text-size": {
          "stops": [
            [
              9,
              8
            ],
            [
              10,
              9
            ]
          ]
        },
        "text-padding": 2,
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto",
        "text-offset": {
          "stops": [
            [
              6,
              [
                0,
                -0.2
              ]
            ],
            [
              11,
              [
                0,
                -0.4
              ]
            ],
            [
              12,
              [
                0,
                -0.6
              ]
            ]
          ]
        },
        "text-letter-spacing": 0,
        "text-keep-upright": true
      },
      "paint": {
        "text-color": "#7a96a0",
        "text-halo-color": "#f5f5f3",
        "text-halo-width": 1
      }
    },
    {
      "id": "tunnel_service_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "service"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              1
            ],
            [
              16,
              3
            ],
            [
              17,
              6
            ],
            [
              18,
              8
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#ddd"
      }
    },
    {
      "id": "tunnel_minor_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 13,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "minor"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "miter"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              0.5
            ],
            [
              12,
              0.5
            ],
            [
              14,
              2
            ],
            [
              15,
              4
            ],
            [
              16,
              6
            ],
            [
              17,
              10
            ],
            [
              18,
              14
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#ddd"
      }
    },
    {
      "id": "tunnel_sec_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 11,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              0.5
            ],
            [
              12,
              1
            ],
            [
              13,
              2
            ],
            [
              14,
              5
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#ddd"
      }
    },
    {
      "id": "tunnel_pri_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 8,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "primary"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.8
            ],
            [
              8,
              1
            ],
            [
              11,
              3
            ],
            [
              13,
              4
            ],
            [
              14,
              6
            ],
            [
              15,
              8
            ],
            [
              16,
              10
            ],
            [
              17,
              14
            ],
            [
              18,
              18
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              5,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": "#ddd"
      }
    },
    {
      "id": "tunnel_trunk_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 5,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "trunk"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.8
            ],
            [
              8,
              1
            ],
            [
              11,
              3
            ],
            [
              13,
              4
            ],
            [
              14,
              6
            ],
            [
              15,
              8
            ],
            [
              16,
              10
            ],
            [
              17,
              14
            ],
            [
              18,
              18
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              5,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": "#ddd"
      }
    },
    {
      "id": "tunnel_mot_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 5,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "motorway"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.8
            ],
            [
              8,
              1
            ],
            [
              11,
              3
            ],
            [
              12,
              4
            ],
            [
              13,
              5
            ],
            [
              14,
              7
            ],
            [
              15,
              9
            ],
            [
              16,
              11
            ],
            [
              17,
              13
            ],
            [
              18,
              22
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": "#ddd"
      }
    },
    {
      "id": "tunnel_path",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "path"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              0.5
            ],
            [
              16,
              1
            ],
            [
              18,
              3
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#d5d5d5",
        "line-dasharray": {
          "stops": [
            [
              15,
              [
                2,
                2
              ]
            ],
            [
              18,
              [
                3,
                3
              ]
            ]
          ]
        }
      }
    },
    {
      "id": "tunnel_service_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "service"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              2
            ],
            [
              16,
              2
            ],
            [
              17,
              4
            ],
            [
              18,
              6
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#eee"
      }
    },
    {
      "id": "tunnel_minor_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "minor"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              3
            ],
            [
              16,
              4
            ],
            [
              17,
              8
            ],
            [
              18,
              12
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "rgba(238, 238, 238, 1)"
      }
    },
    {
      "id": "tunnel_sec_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 13,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              2
            ],
            [
              13,
              2
            ],
            [
              14,
              3
            ],
            [
              15,
              4
            ],
            [
              16,
              6
            ],
            [
              17,
              10
            ],
            [
              18,
              14
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#eee"
      }
    },
    {
      "id": "tunnel_pri_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 11,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "primary"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              1
            ],
            [
              13,
              2
            ],
            [
              14,
              4
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#eee"
      }
    },
    {
      "id": "tunnel_trunk_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 11,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "trunk"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              1
            ],
            [
              13,
              2
            ],
            [
              14,
              4
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#eee"
      }
    },
    {
      "id": "tunnel_mot_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 10,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "motorway"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              10,
              1
            ],
            [
              12,
              2
            ],
            [
              13,
              3
            ],
            [
              14,
              5
            ],
            [
              15,
              7
            ],
            [
              16,
              9
            ],
            [
              17,
              11
            ],
            [
              18,
              20
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#eee"
      }
    },
    {
      "id": "tunnel_rail",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 13,
      "filter": [
        "all",
        [
          "==",
          "class",
          "rail"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "visibility": "visible",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#dddddd",
        "line-width": {
          "base": 1.3,
          "stops": [
            [
              13,
              0.5
            ],
            [
              14,
              1
            ],
            [
              15,
              1
            ],
            [
              16,
              3
            ],
            [
              21,
              7
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "tunnel_rail_dash",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "class",
          "rail"
        ],
        [
          "==",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "visibility": "visible",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#ffffff",
        "line-width": {
          "base": 1.3,
          "stops": [
            [
              15,
              0.5
            ],
            [
              16,
              1
            ],
            [
              20,
              5
            ]
          ]
        },
        "line-dasharray": {
          "stops": [
            [
              15,
              [
                5,
                5
              ]
            ],
            [
              16,
              [
                6,
                6
              ]
            ]
          ]
        },
        "line-opacity": 0.5
      }
    },
    {
      "id": "road_service_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "service"
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              1
            ],
            [
              16,
              3
            ],
            [
              17,
              6
            ],
            [
              18,
              8
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#ddd"
      }
    },
    {
      "id": "road_minor_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 13,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "minor"
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              0.5
            ],
            [
              12,
              0.5
            ],
            [
              14,
              2
            ],
            [
              15,
              3
            ],
            [
              16,
              4.3
            ],
            [
              17,
              10
            ],
            [
              18,
              14
            ]
          ]
        },
        "line-opacity": 1,
        "line-opacity": 1,
        "line-color": {
          "stops": [
            [
              13,
              "#e6e6e6"
            ],
            [
              15.7,
              "#e6e6e6"
            ],
            [
              16,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "road_pri_case_ramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 12,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "primary"
        ],
        [
          "==",
          "ramp",
          1
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              12,
              2
            ],
            [
              13,
              3
            ],
            [
              14,
              4
            ],
            [
              15,
              5
            ],
            [
              16,
              8
            ],
            [
              17,
              10
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              5,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": "#ddd"
      }
    },
    {
      "id": "road_trunk_case_ramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 12,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "trunk"
        ],
        [
          "==",
          "ramp",
          1
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              12,
              2
            ],
            [
              13,
              3
            ],
            [
              14,
              4
            ],
            [
              15,
              5
            ],
            [
              16,
              8
            ],
            [
              17,
              10
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": {
          "stops": [
            [
              12,
              "#e6e6e6"
            ],
            [
              14,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "road_mot_case_ramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 12,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "motorway"
        ],
        [
          "==",
          "ramp",
          1
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              12,
              2
            ],
            [
              13,
              3
            ],
            [
              14,
              4
            ],
            [
              15,
              5
            ],
            [
              16,
              8
            ],
            [
              17,
              10
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": {
          "stops": [
            [
              12,
              "#e6e6e6"
            ],
            [
              14,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "road_sec_case_noramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 11,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              0.5
            ],
            [
              12,
              1.5
            ],
            [
              13,
              3
            ],
            [
              14,
              5
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": {
          "stops": [
            [
              11,
              "#e6e6e6"
            ],
            [
              12.99,
              "#e6e6e6"
            ],
            [
              13,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "road_pri_case_noramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 7,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "primary"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.8
            ],
            [
              8,
              1
            ],
            [
              11,
              3
            ],
            [
              13,
              4
            ],
            [
              14,
              6
            ],
            [
              15,
              8
            ],
            [
              16,
              10
            ],
            [
              17,
              14
            ],
            [
              18,
              18
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              5,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": {
          "stops": [
            [
              7,
              "#e6e6e6"
            ],
            [
              12,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "road_trunk_case_noramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 5,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "trunk"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.8
            ],
            [
              8,
              1
            ],
            [
              11,
              3
            ],
            [
              13,
              4
            ],
            [
              14,
              6
            ],
            [
              15,
              8
            ],
            [
              16,
              10
            ],
            [
              17,
              14
            ],
            [
              18,
              18
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              5,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": {
          "stops": [
            [
              5,
              "#e6e6e6"
            ],
            [
              12,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "road_mot_case_noramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 5,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "motorway"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.7
            ],
            [
              8,
              0.8
            ],
            [
              11,
              3
            ],
            [
              12,
              4
            ],
            [
              13,
              5
            ],
            [
              14,
              7
            ],
            [
              15,
              9
            ],
            [
              16,
              11
            ],
            [
              17,
              13
            ],
            [
              18,
              22
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": {
          "stops": [
            [
              5,
              "#e6e6e6"
            ],
            [
              12,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "road_path",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "in",
          "class",
          "path",
          "track"
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              0.5
            ],
            [
              16,
              1
            ],
            [
              18,
              3
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#d5d5d5",
        "line-dasharray": {
          "stops": [
            [
              15,
              [
                2,
                2
              ]
            ],
            [
              18,
              [
                3,
                3
              ]
            ]
          ]
        }
      }
    },
    {
      "id": "road_service_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "service"
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              2
            ],
            [
              16,
              2
            ],
            [
              17,
              4
            ],
            [
              18,
              6
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fdfdfd"
      }
    },
    {
      "id": "road_minor_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "minor"
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              3
            ],
            [
              16,
              4
            ],
            [
              17,
              8
            ],
            [
              18,
              12
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fdfdfd"
      }
    },
    {
      "id": "road_pri_fill_ramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 12,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "primary"
        ],
        [
          "==",
          "ramp",
          1
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              12,
              1
            ],
            [
              13,
              1.5
            ],
            [
              14,
              2
            ],
            [
              15,
              3
            ],
            [
              16,
              6
            ],
            [
              17,
              8
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "road_trunk_fill_ramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 12,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "trunk"
        ],
        [
          "==",
          "ramp",
          1
        ]
      ],
      "layout": {
        "line-cap": "square",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              12,
              1
            ],
            [
              13,
              1.5
            ],
            [
              14,
              2
            ],
            [
              15,
              3
            ],
            [
              16,
              6
            ],
            [
              17,
              8
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "road_mot_fill_ramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 12,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "motorway"
        ],
        [
          "==",
          "ramp",
          1
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              12,
              1
            ],
            [
              13,
              1.5
            ],
            [
              14,
              2
            ],
            [
              15,
              3
            ],
            [
              16,
              6
            ],
            [
              17,
              8
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "road_sec_fill_noramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 13,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              2
            ],
            [
              13,
              2
            ],
            [
              14,
              3
            ],
            [
              15,
              4
            ],
            [
              16,
              6
            ],
            [
              17,
              10
            ],
            [
              18,
              14
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "road_pri_fill_noramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 10,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "primary"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              10,
              0.3
            ],
            [
              13,
              2
            ],
            [
              14,
              4
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "road_trunk_fill_noramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 10,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "trunk"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              1
            ],
            [
              13,
              2
            ],
            [
              14,
              4
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "road_mot_fill_noramp",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 10,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "motorway"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "!has",
          "brunnel"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              10,
              1
            ],
            [
              12,
              2
            ],
            [
              13,
              3
            ],
            [
              14,
              5
            ],
            [
              15,
              7
            ],
            [
              16,
              9
            ],
            [
              17,
              11
            ],
            [
              18,
              20
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "rail",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 13,
      "filter": [
        "all",
        [
          "==",
          "class",
          "rail"
        ],
        [
          "!=",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "visibility": "visible",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#dddddd",
        "line-width": {
          "base": 1.3,
          "stops": [
            [
              13,
              0.5
            ],
            [
              14,
              1
            ],
            [
              15,
              1
            ],
            [
              16,
              3
            ],
            [
              21,
              7
            ]
          ]
        }
      }
    },
    {
      "id": "rail_dash",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "class",
          "rail"
        ],
        [
          "!=",
          "brunnel",
          "tunnel"
        ]
      ],
      "layout": {
        "visibility": "visible",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#ffffff",
        "line-width": {
          "base": 1.3,
          "stops": [
            [
              15,
              0.5
            ],
            [
              16,
              1
            ],
            [
              20,
              5
            ]
          ]
        },
        "line-dasharray": {
          "stops": [
            [
              15,
              [
                5,
                5
              ]
            ],
            [
              16,
              [
                6,
                6
              ]
            ]
          ]
        }
      }
    },
    {
      "id": "bridge_service_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "service"
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              1
            ],
            [
              16,
              3
            ],
            [
              17,
              6
            ],
            [
              18,
              8
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#ddd"
      }
    },
    {
      "id": "bridge_minor_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 13,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "minor"
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "miter"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              0.5
            ],
            [
              12,
              0.5
            ],
            [
              14,
              2
            ],
            [
              15,
              3
            ],
            [
              16,
              4.3
            ],
            [
              17,
              10
            ],
            [
              18,
              14
            ]
          ]
        },
        "line-opacity": 1,
        "line-opacity": 1,
        "line-color": {
          "stops": [
            [
              13,
              "#e6e6e6"
            ],
            [
              15.7,
              "#e6e6e6"
            ],
            [
              16,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "bridge_sec_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 11,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "miter"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              0.5
            ],
            [
              12,
              1.5
            ],
            [
              13,
              3
            ],
            [
              14,
              5
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": {
          "stops": [
            [
              11,
              "#e6e6e6"
            ],
            [
              12.99,
              "#e6e6e6"
            ],
            [
              13,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "bridge_pri_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 8,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "primary"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.8
            ],
            [
              8,
              1
            ],
            [
              11,
              3
            ],
            [
              13,
              4
            ],
            [
              14,
              6
            ],
            [
              15,
              8
            ],
            [
              16,
              10
            ],
            [
              17,
              14
            ],
            [
              18,
              18
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              5,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": {
          "stops": [
            [
              8,
              "#e6e6e6"
            ],
            [
              12,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "bridge_trunk_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 5,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "trunk"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.8
            ],
            [
              8,
              1
            ],
            [
              11,
              3
            ],
            [
              13,
              4
            ],
            [
              14,
              6
            ],
            [
              15,
              8
            ],
            [
              16,
              10
            ],
            [
              17,
              14
            ],
            [
              18,
              18
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              5,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": {
          "stops": [
            [
              5,
              "#e6e6e6"
            ],
            [
              12,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "bridge_mot_case",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 5,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "motorway"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              0.8
            ],
            [
              8,
              1
            ],
            [
              11,
              3
            ],
            [
              12,
              4
            ],
            [
              13,
              5
            ],
            [
              14,
              7
            ],
            [
              15,
              9
            ],
            [
              16,
              11
            ],
            [
              17,
              13
            ],
            [
              18,
              22
            ]
          ]
        },
        "line-opacity": {
          "stops": [
            [
              6,
              0.5
            ],
            [
              7,
              1
            ]
          ]
        },
        "line-color": {
          "stops": [
            [
              5,
              "#e6e6e6"
            ],
            [
              10,
              "#ddd"
            ]
          ]
        }
      }
    },
    {
      "id": "bridge_path",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "path"
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              0.5
            ],
            [
              16,
              1
            ],
            [
              18,
              3
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#d5d5d5",
        "line-dasharray": {
          "stops": [
            [
              15,
              [
                2,
                2
              ]
            ],
            [
              18,
              [
                3,
                3
              ]
            ]
          ]
        }
      }
    },
    {
      "id": "bridge_service_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "service"
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              2
            ],
            [
              16,
              2
            ],
            [
              17,
              4
            ],
            [
              18,
              6
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fdfdfd"
      }
    },
    {
      "id": "bridge_minor_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 15,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "minor"
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              15,
              3
            ],
            [
              16,
              4
            ],
            [
              17,
              8
            ],
            [
              18,
              12
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fdfdfd"
      }
    },
    {
      "id": "bridge_sec_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 13,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              2
            ],
            [
              13,
              2
            ],
            [
              14,
              3
            ],
            [
              15,
              4
            ],
            [
              16,
              6
            ],
            [
              17,
              10
            ],
            [
              18,
              14
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "bridge_pri_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 11,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "primary"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              1
            ],
            [
              13,
              2
            ],
            [
              14,
              4
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "bridge_trunk_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 11,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "trunk"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round",
        "visibility": "visible"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              11,
              1
            ],
            [
              13,
              2
            ],
            [
              14,
              4
            ],
            [
              15,
              6
            ],
            [
              16,
              8
            ],
            [
              17,
              12
            ],
            [
              18,
              16
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "bridge_mot_fill",
      "type": "line",
      "source": "carto",
      "source-layer": "transportation",
      "minzoom": 10,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "class",
          "motorway"
        ],
        [
          "!=",
          "ramp",
          1
        ],
        [
          "==",
          "brunnel",
          "bridge"
        ]
      ],
      "layout": {
        "line-cap": "butt",
        "line-join": "round"
      },
      "paint": {
        "line-width": {
          "stops": [
            [
              10,
              1
            ],
            [
              12,
              2
            ],
            [
              13,
              3
            ],
            [
              14,
              5
            ],
            [
              15,
              7
            ],
            [
              16,
              9
            ],
            [
              17,
              11
            ],
            [
              18,
              20
            ]
          ]
        },
        "line-opacity": 1,
        "line-color": "#fff"
      }
    },
    {
      "id": "building",
      "type": "fill",
      "source": "carto",
      "source-layer": "building",
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-color": {
          "base": 1,
          "stops": [
            [
              15.5,
              "#dfdfdf"
            ],
            [
              16,
              "#dfdfdf"
            ]
          ]
        },
        "fill-antialias": true
      }
    },
    {
      "id": "building-top",
      "type": "fill",
      "source": "carto",
      "source-layer": "building",
      "layout": {
        "visibility": "visible"
      },
      "paint": {
        "fill-translate": {
          "base": 1,
          "stops": [
            [
              14,
              [
                0,
                0
              ]
            ],
            [
              16,
              [
                -2,
                -2
              ]
            ]
          ]
        },
        "fill-outline-color": "#dfdfdf",
        "fill-color": "#ededed",
        "fill-opacity": {
          "base": 1,
          "stops": [
            [
              13,
              0
            ],
            [
              16,
              1
            ]
          ]
        }
      }
    },
    {
      "id": "boundary_country_outline",
      "type": "line",
      "source": "carto",
      "source-layer": "boundary",
      "minzoom": 6,
      "maxzoom": 24,
      "filter": [
        "all",
        [
          "==",
          "admin_level",
          2
        ],
        [
          "==",
          "maritime",
          0
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": "#f3efed",
        "line-opacity": 0.5,
        "line-width": 8,
        "line-offset": 0
      }
    },
    {
      "id": "boundary_country_inner",
      "type": "line",
      "source": "carto",
      "source-layer": "boundary",
      "minzoom": 0,
      "filter": [
        "all",
        [
          "==",
          "admin_level",
          2
        ],
        [
          "==",
          "maritime",
          0
        ]
      ],
      "layout": {
        "line-cap": "round",
        "line-join": "round"
      },
      "paint": {
        "line-color": {
          "stops": [
            [
              4,
              "#f2e6e7"
            ],
            [
              5,
              "#ebd6d8"
            ],
            [
              6,
              "#ebd6d8"
            ]
          ]
        },
        "line-opacity": 1,
        "line-width": {
          "stops": [
            [
              3,
              1
            ],
            [
              6,
              1.5
            ]
          ]
        },
        "line-offset": 0
      }
    },
    {
      "id": "watername_ocean",
      "type": "symbol",
      "source": "carto",
      "source-layer": "water_name",
      "minzoom": 0,
      "maxzoom": 5,
      "filter": [
        "all",
        [
          "has",
          "name"
        ],
        [
          "==",
          "$type",
          "Point"
        ],
        [
          "==",
          "class",
          "ocean"
        ]
      ],
      "layout": {
        "text-field": "{name}",
        "symbol-placement": "point",
        "text-size": {
          "stops": [
            [
              0,
              13
            ],
            [
              2,
              14
            ],
            [
              4,
              18
            ]
          ]
        },
        "text-font": [
          "Montserrat Medium Italic",
          "Open Sans Italic",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-line-height": 1.2,
        "text-padding": 2,
        "text-allow-overlap": false,
        "text-ignore-placement": false,
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto",
        "text-max-width": 6,
        "text-letter-spacing": 0.1
      },
      "paint": {
        "text-color": "#abb6be",
        "text-halo-color": "#d4dadc",
        "text-halo-width": 1,
        "text-halo-blur": 0
      }
    },
    {
      "id": "watername_sea",
      "type": "symbol",
      "source": "carto",
      "source-layer": "water_name",
      "minzoom": 5,
      "filter": [
        "all",
        [
          "has",
          "name"
        ],
        [
          "==",
          "$type",
          "Point"
        ],
        [
          "==",
          "class",
          "sea"
        ]
      ],
      "layout": {
        "text-field": "{name}",
        "symbol-placement": "point",
        "text-size": 12,
        "text-font": [
          "Montserrat Medium Italic",
          "Open Sans Italic",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-line-height": 1.2,
        "text-padding": 2,
        "text-allow-overlap": false,
        "text-ignore-placement": false,
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto",
        "text-max-width": 6,
        "text-letter-spacing": 0.1
      },
      "paint": {
        "text-color": "#abb6be",
        "text-halo-color": "#d4dadc",
        "text-halo-width": 1,
        "text-halo-blur": 0
      }
    },
    {
      "id": "watername_lake",
      "type": "symbol",
      "source": "carto",
      "source-layer": "water_name",
      "minzoom": 4,
      "filter": [
        "all",
        [
          "has",
          "name"
        ],
        [
          "==",
          "$type",
          "Point"
        ],
        [
          "==",
          "class",
          "lake"
        ]
      ],
      "layout": {
        "text-field": {
          "stops": [
            [
              8,
              "{name_en}"
            ],
            [
              13,
              "{name}"
            ]
          ]
        },
        "symbol-placement": "point",
        "text-size": {
          "stops": [
            [
              13,
              9
            ],
            [
              14,
              10
            ],
            [
              15,
              11
            ],
            [
              16,
              12
            ],
            [
              17,
              13
            ]
          ]
        },
        "text-font": [
          "Montserrat Regular Italic",
          "Open Sans Italic",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-line-height": 1.2,
        "text-padding": 2,
        "text-allow-overlap": false,
        "text-ignore-placement": false,
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto"
      },
      "paint": {
        "text-color": "#7a96a0",
        "text-halo-color": "#f5f5f3",
        "text-halo-width": 1,
        "text-halo-blur": 1
      }
    },
    {
      "id": "watername_lake_line",
      "type": "symbol",
      "source": "carto",
      "source-layer": "water_name",
      "filter": [
        "all",
        [
          "has",
          "name"
        ],
        [
          "==",
          "$type",
          "LineString"
        ]
      ],
      "layout": {
        "text-field": {
          "stops": [
            [
              8,
              "{name_en}"
            ],
            [
              13,
              "{name}"
            ]
          ]
        },
        "symbol-placement": "line",
        "text-size": {
          "stops": [
            [
              13,
              9
            ],
            [
              14,
              10
            ],
            [
              15,
              11
            ],
            [
              16,
              12
            ],
            [
              17,
              13
            ]
          ]
        },
        "text-font": [
          "Montserrat Regular Italic",
          "Open Sans Italic",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "symbol-spacing": 350,
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto",
        "text-line-height": 1.2
      },
      "paint": {
        "text-color": "#7a96a0",
        "text-halo-color": "#f5f5f3",
        "text-halo-width": 1,
        "text-halo-blur": 1
      }
    },
    {
      "id": "place_hamlet",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 12,
      "maxzoom": 16,
      "filter": [
        "any",
        [
          "==",
          "class",
          "neighbourhood"
        ],
        [
          "==",
          "class",
          "hamlet"
        ]
      ],
      "layout": {
        "text-field": {
          "stops": [
            [
              8,
              "{name_en}"
            ],
            [
              14,
              "{name}"
            ]
          ]
        },
        "text-font": [
          "Montserrat Regular",
          "Open Sans Regular",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              13,
              8
            ],
            [
              14,
              10
            ],
            [
              16,
              11
            ]
          ]
        },
        "icon-image": "",
        "icon-offset": [
          16,
          0
        ],
        "text-anchor": "center",
        "icon-size": 1,
        "text-max-width": 10,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ],
        "text-transform": {
          "stops": [
            [
              12,
              "none"
            ],
            [
              14,
              "uppercase"
            ]
          ]
        }
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_suburbs",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 12,
      "maxzoom": 16,
      "filter": [
        "all",
        [
          "==",
          "class",
          "suburb"
        ]
      ],
      "layout": {
        "text-field": {
          "stops": [
            [
              8,
              "{name_en}"
            ],
            [
              13,
              "{name}"
            ]
          ]
        },
        "text-font": [
          "Montserrat Regular",
          "Open Sans Regular",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              12,
              9
            ],
            [
              13,
              10
            ],
            [
              14,
              11
            ],
            [
              15,
              12
            ],
            [
              16,
              13
            ]
          ]
        },
        "icon-image": "",
        "icon-offset": [
          16,
          0
        ],
        "text-anchor": "center",
        "icon-size": 1,
        "text-max-width": 10,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ],
        "text-transform": {
          "stops": [
            [
              8,
              "none"
            ],
            [
              12,
              "uppercase"
            ]
          ]
        }
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_villages",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 10,
      "maxzoom": 16,
      "filter": [
        "all",
        [
          "==",
          "class",
          "village"
        ]
      ],
      "layout": {
        "text-field": {
          "stops": [
            [
              8,
              "{name_en}"
            ],
            [
              13,
              "{name}"
            ]
          ]
        },
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              10,
              9
            ],
            [
              12,
              10
            ],
            [
              13,
              11
            ],
            [
              14,
              12
            ],
            [
              16,
              13
            ]
          ]
        },
        "icon-image": "",
        "icon-offset": [
          16,
          0
        ],
        "text-anchor": "center",
        "icon-size": 1,
        "text-max-width": 10,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ],
        "text-transform": "none"
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_town",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 8,
      "maxzoom": 14,
      "filter": [
        "all",
        [
          "==",
          "class",
          "town"
        ]
      ],
      "layout": {
        "text-field": {
          "stops": [
            [
              8,
              "{name_en}"
            ],
            [
              13,
              "{name}"
            ]
          ]
        },
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              8,
              10
            ],
            [
              9,
              10
            ],
            [
              10,
              11
            ],
            [
              13,
              14
            ],
            [
              14,
              15
            ]
          ]
        },
        "icon-image": "",
        "icon-offset": [
          16,
          0
        ],
        "text-anchor": "center",
        "icon-size": 1,
        "text-max-width": 10,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ],
        "text-transform": "none"
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_country_2",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 3,
      "maxzoom": 10,
      "filter": [
        "all",
        [
          "==",
          "class",
          "country"
        ],
        [
          ">=",
          "rank",
          3
        ],
        [
          "has",
          "iso_a2"
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              3,
              10
            ],
            [
              5,
              11
            ],
            [
              6,
              12
            ],
            [
              7,
              13
            ],
            [
              8,
              14
            ]
          ]
        },
        "text-transform": "uppercase"
      },
      "paint": {
        "text-color": {
          "stops": [
            [
              3,
              "#8a99a4"
            ],
            [
              5,
              "#a1adb6"
            ],
            [
              6,
              "#b9c2c9"
            ]
          ]
        },
        "text-halo-color": "#fafaf8",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_country_1",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 2,
      "maxzoom": 7,
      "filter": [
        "all",
        [
          "==",
          "class",
          "country"
        ],
        [
          "<=",
          "rank",
          2
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              3,
              11
            ],
            [
              4,
              12
            ],
            [
              5,
              13
            ],
            [
              6,
              14
            ]
          ]
        },
        "text-transform": "uppercase",
        "text-max-width": {
          "stops": [
            [
              2,
              6
            ],
            [
              3,
              6
            ],
            [
              4,
              9
            ],
            [
              5,
              12
            ]
          ]
        }
      },
      "paint": {
        "text-color": {
          "stops": [
            [
              3,
              "#8a99a4"
            ],
            [
              5,
              "#a1adb6"
            ],
            [
              6,
              "#b9c2c9"
            ]
          ]
        },
        "text-halo-color": "#fafaf8",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_state",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 5,
      "maxzoom": 10,
      "filter": [
        "all",
        [
          "==",
          "class",
          "state"
        ],
        [
          "<=",
          "rank",
          4
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              5,
              12
            ],
            [
              7,
              14
            ]
          ]
        },
        "text-transform": "uppercase",
        "text-max-width": 9
      },
      "paint": {
        "text-color": "#97a4ae",
        "text-halo-color": "#fafaf8",
        "text-halo-width": 0
      }
    },
    {
      "id": "place_continent",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 0,
      "maxzoom": 2,
      "filter": [
        "all",
        [
          "==",
          "class",
          "continent"
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-transform": "uppercase",
        "text-size": 14,
        "text-letter-spacing": 0.1,
        "text-max-width": 9,
        "text-justify": "center",
        "text-keep-upright": false
      },
      "paint": {
        "text-color": "#697b89",
        "text-halo-color": "#fafaf8",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_city_r6",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 8,
      "maxzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "class",
          "city"
        ],
        [
          ">=",
          "rank",
          6
        ]
      ],
      "layout": {
        "text-field": {
          "stops": [
            [
              8,
              "{name_en}"
            ],
            [
              13,
              "{name}"
            ]
          ]
        },
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              8,
              12
            ],
            [
              9,
              13
            ],
            [
              10,
              14
            ],
            [
              13,
              17
            ],
            [
              14,
              20
            ]
          ]
        },
        "icon-image": "",
        "icon-offset": [
          16,
          0
        ],
        "text-anchor": "center",
        "icon-size": 1,
        "text-max-width": 10,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ],
        "text-transform": "uppercase"
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_city_r5",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 8,
      "maxzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "class",
          "city"
        ],
        [
          ">=",
          "rank",
          0
        ],
        [
          "<=",
          "rank",
          5
        ]
      ],
      "layout": {
        "text-field": {
          "stops": [
            [
              8,
              "{name_en}"
            ],
            [
              13,
              "{name}"
            ]
          ]
        },
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              8,
              14
            ],
            [
              10,
              16
            ],
            [
              13,
              19
            ],
            [
              14,
              22
            ]
          ]
        },
        "icon-image": "",
        "icon-offset": [
          16,
          0
        ],
        "text-anchor": "center",
        "icon-size": 1,
        "text-max-width": 10,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ],
        "text-transform": "uppercase"
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_city_dot_r7",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 6,
      "maxzoom": 7,
      "filter": [
        "all",
        [
          "==",
          "class",
          "city"
        ],
        [
          "<=",
          "rank",
          7
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": 12,
        "icon-image": "circle-11",
        "icon-offset": [
          16,
          5
        ],
        "text-anchor": "right",
        "icon-size": 0.4,
        "text-max-width": 8,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ]
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_city_dot_r4",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 5,
      "maxzoom": 7,
      "filter": [
        "all",
        [
          "==",
          "class",
          "city"
        ],
        [
          "<=",
          "rank",
          4
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": 12,
        "icon-image": "circle-11",
        "icon-offset": [
          16,
          5
        ],
        "text-anchor": "right",
        "icon-size": 0.4,
        "text-max-width": 8,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ]
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_city_dot_r2",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 4,
      "maxzoom": 7,
      "filter": [
        "all",
        [
          "==",
          "class",
          "city"
        ],
        [
          "<=",
          "rank",
          2
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": 12,
        "icon-image": "circle-11",
        "icon-offset": [
          16,
          5
        ],
        "text-anchor": "right",
        "icon-size": 0.4,
        "text-max-width": 8,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ]
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_city_dot_z7",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 7,
      "maxzoom": 8,
      "filter": [
        "all",
        [
          "!has",
          "capital"
        ],
        [
          "!in",
          "class",
          "country",
          "state"
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": 12,
        "icon-image": "circle-11",
        "icon-offset": [
          16,
          5
        ],
        "text-anchor": "right",
        "icon-size": 0.4,
        "text-max-width": 8,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ]
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "place_capital_dot_z7",
      "type": "symbol",
      "source": "carto",
      "source-layer": "place",
      "minzoom": 7,
      "maxzoom": 8,
      "filter": [
        "all",
        [
          ">",
          "capital",
          0
        ]
      ],
      "layout": {
        "text-field": "{name_en}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": 12,
        "icon-image": "circle-11",
        "icon-offset": [
          16,
          5
        ],
        "text-anchor": "right",
        "icon-size": 0.4,
        "text-max-width": 8,
        "text-keep-upright": true,
        "text-offset": [
          0.2,
          0.2
        ],
        "text-transform": "uppercase"
      },
      "paint": {
        "text-color": "#697b89",
        "icon-color": "#697b89",
        "icon-translate-anchor": "map",
        "text-halo-color": "rgba(255,255,255,0.5)",
        "text-halo-width": 1
      }
    },
    {
      "id": "poi_stadium",
      "type": "symbol",
      "source": "carto",
      "source-layer": "poi",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "in",
          "class",
          "stadium",
          "cemetery",
          "attraction"
        ],
        [
          "<=",
          "rank",
          3
        ]
      ],
      "layout": {
        "text-field": "{name}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              15,
              8
            ],
            [
              17,
              9
            ],
            [
              18,
              10
            ]
          ]
        },
        "text-transform": "uppercase"
      },
      "paint": {
        "text-color": "#7d9c83",
        "text-halo-color": "#f5f5f3",
        "text-halo-width": 1
      }
    },
    {
      "id": "poi_park",
      "type": "symbol",
      "source": "carto",
      "source-layer": "poi",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "==",
          "class",
          "park"
        ]
      ],
      "layout": {
        "text-field": "{name}",
        "text-font": [
          "Montserrat Medium",
          "Open Sans Bold",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              15,
              8
            ],
            [
              17,
              9
            ],
            [
              18,
              10
            ]
          ]
        },
        "text-transform": "uppercase"
      },
      "paint": {
        "text-color": "#7d9c83",
        "text-halo-color": "#f5f5f3",
        "text-halo-width": 1
      }
    },
    {
      "id": "roadname_minor",
      "type": "symbol",
      "source": "carto",
      "source-layer": "transportation_name",
      "minzoom": 16,
      "filter": [
        "all",
        [
          "in",
          "class",
          "minor",
          "service"
        ]
      ],
      "layout": {
        "symbol-placement": "line",
        "text-font": [
          "Montserrat Regular",
          "Open Sans Regular",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": 9,
        "text-field": "{name}",
        "symbol-avoid-edges": false,
        "symbol-spacing": 200,
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto",
        "text-justify": "center"
      },
      "paint": {
        "text-color": "#838383",
        "text-halo-color": "#fff",
        "text-halo-width": 1
      }
    },
    {
      "id": "roadname_sec",
      "type": "symbol",
      "source": "carto",
      "source-layer": "transportation_name",
      "minzoom": 15,
      "filter": [
        "all",
        [
          "in",
          "class",
          "secondary",
          "tertiary"
        ]
      ],
      "layout": {
        "symbol-placement": "line",
        "text-font": [
          "Montserrat Regular",
          "Open Sans Regular",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              15,
              9
            ],
            [
              16,
              11
            ],
            [
              18,
              12
            ]
          ]
        },
        "text-field": "{name}",
        "symbol-avoid-edges": false,
        "symbol-spacing": 200,
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto",
        "text-justify": "center"
      },
      "paint": {
        "text-color": "#838383",
        "text-halo-color": "#fff",
        "text-halo-width": 1
      }
    },
    {
      "id": "roadname_pri",
      "type": "symbol",
      "source": "carto",
      "source-layer": "transportation_name",
      "minzoom": 14,
      "filter": [
        "all",
        [
          "in",
          "class",
          "primary"
        ]
      ],
      "layout": {
        "symbol-placement": "line",
        "text-font": [
          "Montserrat Regular",
          "Open Sans Regular",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              14,
              10
            ],
            [
              15,
              10
            ],
            [
              16,
              11
            ],
            [
              18,
              12
            ]
          ]
        },
        "text-field": "{name}",
        "symbol-avoid-edges": false,
        "symbol-spacing": {
          "stops": [
            [
              6,
              200
            ],
            [
              16,
              250
            ]
          ]
        },
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto",
        "text-justify": "center",
        "text-letter-spacing": {
          "stops": [
            [
              14,
              0
            ],
            [
              16,
              0.2
            ]
          ]
        }
      },
      "paint": {
        "text-color": "#838383",
        "text-halo-color": "#fff",
        "text-halo-width": 1
      }
    },
    {
      "id": "roadname_major",
      "type": "symbol",
      "source": "carto",
      "source-layer": "transportation_name",
      "minzoom": 13,
      "filter": [
        "all",
        [
          "in",
          "class",
          "trunk",
          "motorway"
        ]
      ],
      "layout": {
        "symbol-placement": "line",
        "text-font": [
          "Montserrat Regular",
          "Open Sans Regular",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ],
        "text-size": {
          "stops": [
            [
              14,
              10
            ],
            [
              15,
              10
            ],
            [
              16,
              11
            ],
            [
              18,
              12
            ]
          ]
        },
        "text-field": "{name}",
        "symbol-avoid-edges": false,
        "symbol-spacing": {
          "stops": [
            [
              6,
              200
            ],
            [
              16,
              250
            ]
          ]
        },
        "text-pitch-alignment": "auto",
        "text-rotation-alignment": "auto",
        "text-justify": "center",
        "text-letter-spacing": {
          "stops": [
            [
              13,
              0
            ],
            [
              16,
              0.2
            ]
          ]
        }
      },
      "paint": {
        "text-color": "#838383",
        "text-halo-color": "#fff",
        "text-halo-width": 1
      }
    },
    {
      "id": "housenumber",
      "type": "symbol",
      "source": "carto",
      "source-layer": "housenumber",
      "minzoom": 17,
      "maxzoom": 24,
      "layout": {
        "text-field": "{housenumber}",
        "text-size": {
          "stops": [
            [
              17,
              9
            ],
            [
              18,
              11
            ]
          ]
        },
        "text-font": [
          "Montserrat Regular",
          "Open Sans Regular",
          "Noto Sans Regular",
          "HanWangHeiLight Regular",
          "NanumBarunGothic Regular"
        ]
      },
      "paint": {
        "text-halo-color": "transparent",
        "text-color": "transparent",
        "text-halo-width": 0.75
      }
    }
  ],
  "id": "voyager",
  "owner": "Carto"
}
